Interface BackgroundAccessor.BackgroundProperty<T>
- Type Parameters:
T- The background's type to be accessed.
- All Superinterfaces:
BackgroundAccessor<T>, BackgroundAccessor.BackgroundMutator<T>
- Enclosing interface:
BackgroundAccessor<T>
public static interface BackgroundAccessor.BackgroundProperty<T>
extends BackgroundAccessor<T>, BackgroundAccessor.BackgroundMutator<T>
Provides a background property.
-
Nested Class Summary
Nested classes/interfaces inherited from interface BackgroundAccessor
BackgroundAccessor.BackgroundBuilder<T,B>, BackgroundAccessor.BackgroundMutator<T>, BackgroundAccessor.BackgroundProperty<T> -
Method Summary
Modifier and TypeMethodDescriptiondefault TletBackground(T aBackground) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the given background (setter) as ofBackgroundAccessor.BackgroundMutator.setBackground(Object)and returns the very same value (getter).Methods inherited from interface BackgroundAccessor
getBackgroundMethods inherited from interface BackgroundAccessor.BackgroundMutator
setBackground
-
Method Details
-
letBackground
This method stores and passes through the given argument, which is very useful for builder APIs: Sets the given background (setter) as ofBackgroundAccessor.BackgroundMutator.setBackground(Object)and returns the very same value (getter).- Parameters:
aBackground- The background to set (viaBackgroundAccessor.BackgroundMutator.setBackground(Object)).- Returns:
- Returns the value passed for it to be used in conclusive processing steps.
-