Interface BottomPaddingAccessor
- All Known Subinterfaces:
BottomPaddingAccessor.BottomPaddingProperty, Padding, Padding.PaddingAccessor, Padding.PaddingProperty
public interface BottomPaddingAccessor
Provides an accessor for a bottom padding property.
-
Nested Class Summary
Nested ClassesModifier and TypeInterfaceDescriptionstatic interfaceProvides a builder method for a bottom padding property returning the builder for applying multiple build operations.static interfaceProvides a mutator for a bottom padding property.static interfaceProvides a bottom padding property. -
Method Summary
Modifier and TypeMethodDescriptionintRetrieves the bottom padding from the bottom padding property.
-
Method Details
-
getBottomPadding
int getBottomPadding()Retrieves the bottom padding from the bottom padding property.- Returns:
- The bottom padding stored by the bottom padding property.
-