Interface BottomPaddingAccessor.BottomPaddingBuilder<B extends BottomPaddingAccessor.BottomPaddingBuilder<B>>
- Type Parameters:
B- The builder to return in order to be able to apply multiple build operations.
- All Known Subinterfaces:
Padding.PaddingBuilder<B>
- Enclosing interface:
BottomPaddingAccessor
public static interface BottomPaddingAccessor.BottomPaddingBuilder<B extends BottomPaddingAccessor.BottomPaddingBuilder<B>>
Provides a builder method for a bottom padding property returning the
builder for applying multiple build operations.
-
Method Summary
Modifier and TypeMethodDescriptionwithBottomPadding(int aBottomPadding) Sets the bottom padding for the bottom padding property.
-
Method Details
-
withBottomPadding
Sets the bottom padding for the bottom padding property.- Parameters:
aBottomPadding- The bottom padding to be stored by the bottom padding property.- Returns:
- The builder for applying multiple build operations.
-