Interface BottomPaddingAccessor.BottomPaddingMutator
- All Known Subinterfaces:
BottomPaddingAccessor.BottomPaddingProperty, Padding.PaddingMutator, Padding.PaddingProperty
- Enclosing interface:
BottomPaddingAccessor
public static interface BottomPaddingAccessor.BottomPaddingMutator
Provides a mutator for a bottom padding property.
-
Method Summary
Modifier and TypeMethodDescriptionvoidsetBottomPadding(int aBottomPadding) Sets the bottom padding for the bottom padding property.
-
Method Details
-
setBottomPadding
void setBottomPadding(int aBottomPadding) Sets the bottom padding for the bottom padding property.- Parameters:
aBottomPadding- The bottom padding to be stored by the bottom padding property.
-