Enum Class BoxBorderMode
- All Implemented Interfaces:
Serializable, Comparable<BoxBorderMode>, Constable
The
BoxBorderMode specifies for according algorithms on how a box is
to be drawn.-
Nested Class Summary
Nested classes/interfaces inherited from class Enum
Enum.EnumDesc<E> -
Enum Constant Summary
Enum ConstantsEnum ConstantDescription -
Method Summary
Modifier and TypeMethodDescriptionstatic BoxBorderModefromBoxBorders(boolean isTopBorder, boolean isRightBorder, boolean isBottomBorder, boolean isLeftBorder) From box borders.booleanChecks if is bottom border.booleanChecks if is left border.booleanChecks if is right border.booleanChecks if is top border.static BoxBorderModeReturns the enum constant of this class with the specified name.static BoxBorderMode[]values()Returns an array containing the constants of this enum class, in the order they are declared.
-
Enum Constant Details
-
NONE
-
LEFT
-
BOTTOM
-
BOTTOM_LEFT
-
RIGHT
-
RIGHT_LEFT
-
RIGHT_BOTTOM
-
RIGHT_BOTTOM_LEFT
-
TOP
-
TOP_LEFT
-
TOP_BOTTOM
-
TOP_BOTTOM_LEFT
-
TOP_RIGHT
-
TOP_RIGHT_LEFT
-
TOP_RIGHT_BOTTOM
-
TOP_RIGHT_BOTTOM_LEFT
-
ALL
-
-
Method Details
-
values
Returns an array containing the constants of this enum class, in the order they are declared.- Returns:
- an array containing the constants of this enum class, in the order they are declared
-
valueOf
Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum class has no constant with the specified nameNullPointerException- if the argument is null
-
isLeftBorder
public boolean isLeftBorder()Checks if is left border.- Returns:
- true, if is left border
-
isTopBorder
public boolean isTopBorder()Checks if is top border.- Returns:
- true, if is top border
-
isRightBorder
public boolean isRightBorder()Checks if is right border.- Returns:
- true, if is right border
-
isBottomBorder
public boolean isBottomBorder()Checks if is bottom border.- Returns:
- true, if is bottom border
-
fromBoxBorders
public static BoxBorderMode fromBoxBorders(boolean isTopBorder, boolean isRightBorder, boolean isBottomBorder, boolean isLeftBorder) From box borders.- Parameters:
isTopBorder- the is top borderisRightBorder- the is right borderisBottomBorder- the is bottom borderisLeftBorder- the is left border- Returns:
- the box border mode
-