- All Known Subinterfaces:
ContainerDimension,ContainerDimension.ContainerDimensionProperty,ContainerHeightAccessor.ContainerHeightProperty
public interface ContainerHeightAccessor
Provides an accessor for a container height property.
-
Nested Class Summary
Nested ClassesModifier and TypeInterfaceDescriptionstatic interfaceContainerHeightAccessor.ContainerHeightBuilder<B extends ContainerHeightAccessor.ContainerHeightBuilder<B>>Provides a builder method for a container height property returning the builder for applying multiple build operations.static interfaceProvides a mutator for a container height property.static interfaceProvides a container height property. -
Method Summary
Modifier and TypeMethodDescriptionintRetrieves the container height from the container height property.
-
Method Details
-
getContainerHeight
int getContainerHeight()Retrieves the container height from the container height property.- Returns:
- The container height stored by the container height property.
-