Interface ContainerHeightAccessor.ContainerHeightMutator
- All Known Subinterfaces:
ContainerDimension.ContainerDimensionMutator, ContainerDimension.ContainerDimensionProperty, ContainerHeightAccessor.ContainerHeightProperty
- Enclosing interface:
ContainerHeightAccessor
public static interface ContainerHeightAccessor.ContainerHeightMutator
Provides a mutator for a container height property.
-
Method Summary
Modifier and TypeMethodDescriptionvoidsetContainerHeight(int aHeight) Sets the container height for the container height property.
-
Method Details
-
setContainerHeight
void setContainerHeight(int aHeight) Sets the container height for the container height property.- Parameters:
aHeight- The container height to be stored by the container height property.
-