Interface ContainerHeightAccessor.ContainerHeightProperty
- All Superinterfaces:
ContainerHeightAccessor, ContainerHeightAccessor.ContainerHeightMutator
- All Known Subinterfaces:
ContainerDimension.ContainerDimensionProperty
- Enclosing interface:
ContainerHeightAccessor
public static interface ContainerHeightAccessor.ContainerHeightProperty
extends ContainerHeightAccessor, ContainerHeightAccessor.ContainerHeightMutator
Provides a container height property.
-
Nested Class Summary
Nested classes/interfaces inherited from interface ContainerHeightAccessor
ContainerHeightAccessor.ContainerHeightBuilder<B>, ContainerHeightAccessor.ContainerHeightMutator, ContainerHeightAccessor.ContainerHeightProperty -
Method Summary
Modifier and TypeMethodDescriptiondefault intletContainerHeight(int aContainerHeight) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the given container height (setter) as ofContainerHeightAccessor.ContainerHeightMutator.setContainerHeight(int)and returns the very same value (getter).Methods inherited from interface ContainerHeightAccessor
getContainerHeightMethods inherited from interface ContainerHeightAccessor.ContainerHeightMutator
setContainerHeight
-
Method Details
-
letContainerHeight
default int letContainerHeight(int aContainerHeight) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the given container height (setter) as ofContainerHeightAccessor.ContainerHeightMutator.setContainerHeight(int)and returns the very same value (getter).- Parameters:
aContainerHeight- The container height to set (viaContainerHeightAccessor.ContainerHeightMutator.setContainerHeight(int)).- Returns:
- Returns the value passed for it to be used in conclusive processing steps.
-