Interface ContainerWidthAccessor
- All Known Subinterfaces:
ContainerDimension, ContainerDimension.ContainerDimensionProperty, ContainerWidthAccessor.ContainerWidthProperty
public interface ContainerWidthAccessor
Provides an accessor for a container width property.
-
Nested Class Summary
Nested ClassesModifier and TypeInterfaceDescriptionstatic interfaceContainerWidthAccessor.ContainerWidthBuilder<B extends ContainerWidthAccessor.ContainerWidthBuilder<B>>Provides a builder method for a container width property returning the builder for applying multiple build operations.static interfaceProvides a mutator for a container width property.static interfaceProvides a container width property. -
Method Summary
Modifier and TypeMethodDescriptionintRetrieves the container width from the container width property.
-
Method Details
-
getContainerWidth
int getContainerWidth()Retrieves the container width from the container width property.- Returns:
- The container width stored by the container width property.
-