Interface ContainerWidthAccessor.ContainerWidthProperty
- All Superinterfaces:
ContainerWidthAccessor, ContainerWidthAccessor.ContainerWidthMutator
- All Known Subinterfaces:
ContainerDimension.ContainerDimensionProperty
- Enclosing interface:
ContainerWidthAccessor
public static interface ContainerWidthAccessor.ContainerWidthProperty
extends ContainerWidthAccessor, ContainerWidthAccessor.ContainerWidthMutator
Provides a container width property.
-
Nested Class Summary
Nested classes/interfaces inherited from interface ContainerWidthAccessor
ContainerWidthAccessor.ContainerWidthBuilder<B>, ContainerWidthAccessor.ContainerWidthMutator, ContainerWidthAccessor.ContainerWidthProperty -
Method Summary
Modifier and TypeMethodDescriptiondefault intletContainerWidth(int aContainerWidth) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the given container width (setter) as ofContainerWidthAccessor.ContainerWidthMutator.setContainerWidth(int)and returns the very same value (getter).Methods inherited from interface ContainerWidthAccessor
getContainerWidthMethods inherited from interface ContainerWidthAccessor.ContainerWidthMutator
setContainerWidth
-
Method Details
-
letContainerWidth
default int letContainerWidth(int aContainerWidth) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the given container width (setter) as ofContainerWidthAccessor.ContainerWidthMutator.setContainerWidth(int)and returns the very same value (getter).- Parameters:
aContainerWidth- The container width to set (viaContainerWidthAccessor.ContainerWidthMutator.setContainerWidth(int)).- Returns:
- Returns the value passed for it to be used in conclusive processing steps.
-