Module org.refcodes.graphical
Package org.refcodes.graphical
Interface ContentAccessor.ContentProperty<T>
-
- Type Parameters:
T- The content's type to be accessed.
- All Superinterfaces:
ContentAccessor<T>,ContentAccessor.ContentMutator<T>
- All Known Subinterfaces:
ViewportPane<C,B>
- Enclosing interface:
- ContentAccessor<T>
public static interface ContentAccessor.ContentProperty<T> extends ContentAccessor<T>, ContentAccessor.ContentMutator<T>
Provides a content property.
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.graphical.ContentAccessor
ContentAccessor.ContentBuilder<T,B extends ContentAccessor.ContentBuilder<T,B>>, ContentAccessor.ContentMutator<T>, ContentAccessor.ContentProperty<T>
-
-
Method Summary
All Methods Instance Methods Default Methods Modifier and Type Method Description default TletContent(T aContent)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the given content (setter) as ofContentAccessor.ContentMutator.setContent(Object)and returns the very same value (getter).-
Methods inherited from interface org.refcodes.graphical.ContentAccessor
getContent
-
Methods inherited from interface org.refcodes.graphical.ContentAccessor.ContentMutator
setContent
-
-
-
-
Method Detail
-
letContent
default T letContent(T aContent)
This method stores and passes through the given argument, which is very useful for builder APIs: Sets the given content (setter) as ofContentAccessor.ContentMutator.setContent(Object)and returns the very same value (getter).- Parameters:
aContent- The content to set (viaContentAccessor.ContentMutator.setContent(Object)).- Returns:
- Returns the value passed for it to be used in conclusive processing steps.
-
-