- All Superinterfaces:
HeightAccessor,WidthAccessor
- All Known Subinterfaces:
Dimension.DimensionProperty,PixmapImageBuilder<PX>,Rectangle,Rectangle.RectangleProperty
- All Known Implementing Classes:
DimensionImpl,RectangleImpl,RgbPixmapImageBuilder
public interface Dimension extends WidthAccessor, HeightAccessor
Provides an accessor for a dimension property (width and height).
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceDimension.DimensionBuilder<B extends Dimension.DimensionBuilder<B>>Provides a builder for a dimension property (width and height).static interfaceDimension.DimensionMutatorProvides a mutator for a dimension property (width and height).static interfaceDimension.DimensionPropertyProvides a property (getter / setter) for a dimension property (width and height).Nested classes/interfaces inherited from interface org.refcodes.graphical.HeightAccessor
HeightAccessor.HeightBuilder<B extends HeightAccessor.HeightBuilder<B>>, HeightAccessor.HeightMutator, HeightAccessor.HeightPropertyNested classes/interfaces inherited from interface org.refcodes.graphical.WidthAccessor
WidthAccessor.WidthBuilder<B extends WidthAccessor.WidthBuilder<B>>, WidthAccessor.WidthMutator, WidthAccessor.WidthProperty -
Method Summary
Static Methods Modifier and Type Method Description static booleanequals(Dimension aDimensionA, Dimension aDimensionB)Equals.Methods inherited from interface org.refcodes.graphical.HeightAccessor
getHeightMethods inherited from interface org.refcodes.graphical.WidthAccessor
getWidth
-
Method Details
-
equals
Equals.- Parameters:
aDimensionA- the dimension AaDimensionB- the dimension B- Returns:
- true, if successful
-