- All Superinterfaces:
Dimension,Dimension.DimensionAccessor,Dimension.DimensionMutator,HeightAccessor,HeightAccessor.HeightMutator,HeightAccessor.HeightProperty,WidthAccessor,WidthAccessor.WidthMutator,WidthAccessor.WidthProperty
- All Known Subinterfaces:
PixmapImageBuilder<PX>,Rectangle.RectangleProperty
- All Known Implementing Classes:
RgbPixmapImageBuilder
- Enclosing interface:
- Dimension
public static interface Dimension.DimensionProperty
extends Dimension.DimensionAccessor, Dimension.DimensionMutator, WidthAccessor.WidthProperty, HeightAccessor.HeightProperty
Provides a property (getter / setter) for a dimension property (width and
height).
-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.graphical.Dimension
Dimension.DimensionAccessor, Dimension.DimensionBuilder<B extends Dimension.DimensionBuilder<B>>, Dimension.DimensionMutator, Dimension.DimensionPropertyNested classes/interfaces inherited from interface org.refcodes.graphical.HeightAccessor
HeightAccessor.HeightBuilder<B extends HeightAccessor.HeightBuilder<B>>, HeightAccessor.HeightMutator, HeightAccessor.HeightPropertyNested classes/interfaces inherited from interface org.refcodes.graphical.WidthAccessor
WidthAccessor.WidthBuilder<B extends WidthAccessor.WidthBuilder<B>>, WidthAccessor.WidthMutator, WidthAccessor.WidthProperty -
Method Summary
Modifier and TypeMethodDescriptiondefault DimensionletDimension(int aWidth, int aHeight) This method stores and passes through the given arguments, which is very useful for builder APIs: Sets the givenDimension(setter) as ofDimension.DimensionMutator.setDimension(int, int)and returns the very same value encapsulated asDimensioninstance.default DimensionletDimension(Dimension aDimension) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenDimension(setter) as ofDimension.DimensionMutator.setDimension(Dimension)and returns the very same value (getter).Methods inherited from interface org.refcodes.graphical.Dimension.DimensionMutator
setDimension, setDimensionMethods inherited from interface org.refcodes.graphical.HeightAccessor
getHeightMethods inherited from interface org.refcodes.graphical.HeightAccessor.HeightMutator
setHeightMethods inherited from interface org.refcodes.graphical.HeightAccessor.HeightProperty
letHeightMethods inherited from interface org.refcodes.graphical.WidthAccessor
getWidthMethods inherited from interface org.refcodes.graphical.WidthAccessor.WidthMutator
setWidthMethods inherited from interface org.refcodes.graphical.WidthAccessor.WidthProperty
letWidth
-
Method Details
-
letDimension
This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenDimension(setter) as ofDimension.DimensionMutator.setDimension(Dimension)and returns the very same value (getter).- Parameters:
aDimension- TheDimensionto set (viaDimension.DimensionMutator.setDimension(Dimension)).- Returns:
- Returns the value passed for it to be used in conclusive processing steps.
-
letDimension
This method stores and passes through the given arguments, which is very useful for builder APIs: Sets the givenDimension(setter) as ofDimension.DimensionMutator.setDimension(int, int)and returns the very same value encapsulated asDimensioninstance.- Parameters:
aWidth- The widthDimensionto set (viaWidthAccessor.WidthMutator.setWidth(int)).aHeight- The heightDimensionto set (viaHeightAccessor.HeightMutator.setHeight(int)).- Returns:
- Returns the values passed encapsulated in a
Dimensionobject for it to be used in conclusive processing steps.
-