Interface DragOpacityAccessor
- All Known Subinterfaces:
DragOpacityAccessor.DragOpacityProperty, GridViewportPane<C,B>
public interface DragOpacityAccessor
Provides an accessor for a drag opacity property.
-
Nested Class Summary
Nested ClassesModifier and TypeInterfaceDescriptionstatic interfaceProvides a builder method for a drag opacity property returning the builder for applying multiple build operations.static interfaceProvides a mutator for a drag opacity property.static interfaceProvides a drag opacity property. -
Method Summary
Modifier and TypeMethodDescriptiondoubleRetrieves the drag opacity from the drag opacity property.
-
Method Details
-
getDragOpacity
double getDragOpacity()Retrieves the drag opacity from the drag opacity property.- Returns:
- The drag opacity stored by the drag opacity property.
-