Module org.refcodes.graphical
Package org.refcodes.graphical
Interface FieldHeightAccessor.FieldHeightMutator
- All Known Subinterfaces:
FieldDimension.FieldDimensionMutator,FieldDimension.FieldDimensionProperty,FieldHeightAccessor.FieldHeightProperty,GridViewportPane<C,,B> Raster.RasterMutator,Raster.RasterProperty
- All Known Implementing Classes:
RasterPropertyBuilder
- Enclosing interface:
- FieldHeightAccessor
public static interface FieldHeightAccessor.FieldHeightMutator
Provides a mutator for a field height property.
-
Method Summary
Modifier and TypeMethodDescriptionvoidsetFieldHeight(int aHeight) Sets the field height for the field height property.
-
Method Details
-
setFieldHeight
void setFieldHeight(int aHeight) Sets the field height for the field height property.- Parameters:
aHeight- The field height to be stored by the field height property.
-