- All Known Subinterfaces:
FieldDimension,FieldDimension.FieldDimensionAccessor,FieldDimension.FieldDimensionProperty,FieldWidthAccessor.FieldWidthProperty,GridViewportPane<C,,B> Raster,Raster.RasterAccessor,Raster.RasterProperty
- All Known Implementing Classes:
FieldDimensionImpl,RasterImpl,RasterPropertyBuilder
public interface FieldWidthAccessor
Provides an accessor for a field width property.
-
Nested Class Summary
Nested ClassesModifier and TypeInterfaceDescriptionstatic interfaceProvides a builder method for a field width property returning the builder for applying multiple build operations.static interfaceProvides a mutator for a field width property.static interfaceProvides a field width property. -
Method Summary
Modifier and TypeMethodDescriptionintRetrieves the field width from the field width property.
-
Method Details
-
getFieldWidth
int getFieldWidth()Retrieves the field width from the field width property.- Returns:
- The field width stored by the field width property.
-