Module org.refcodes.graphical
Package org.refcodes.graphical
Interface FieldWidthAccessor.FieldWidthMutator
- All Known Subinterfaces:
FieldDimension.FieldDimensionMutator,FieldDimension.FieldDimensionProperty,FieldWidthAccessor.FieldWidthProperty,GridViewportPane<C,,B> Raster.RasterMutator,Raster.RasterProperty
- All Known Implementing Classes:
RasterPropertyBuilder
- Enclosing interface:
- FieldWidthAccessor
public static interface FieldWidthAccessor.FieldWidthMutator
Provides a mutator for a field width property.
-
Method Summary
Modifier and TypeMethodDescriptionvoidsetFieldWidth(int aWidth) Sets the field width for the field width property.
-
Method Details
-
setFieldWidth
void setFieldWidth(int aWidth) Sets the field width for the field width property.- Parameters:
aWidth- The field width to be stored by the field width property.
-