- All Known Subinterfaces:
GridDimension,GridDimension.GridDimensionAccessor,GridDimension.GridDimensionProperty,GridHeightAccessor.GridHeightProperty,Raster,Raster.RasterAccessor,Raster.RasterProperty
- All Known Implementing Classes:
GridDimensionImpl,RasterImpl,RasterPropertyBuilder
public interface GridHeightAccessor
Provides an accessor for a grid height property.
-
Nested Class Summary
Nested ClassesModifier and TypeInterfaceDescriptionstatic interfaceProvides a builder method for a grid height property returning the builder for applying multiple build operations.static interfaceProvides a mutator for a grid height property.static interfaceProvides a grid height property. -
Method Summary
Modifier and TypeMethodDescriptionintRetrieves the grid height from the grid height property.
-
Method Details
-
getGridHeight
int getGridHeight()Retrieves the grid height from the grid height property.- Returns:
- The grid height stored by the grid height property.
-