Interface GridModeAccessor
- All Known Subinterfaces:
GridModeAccessor.GridModeProperty, GridViewportPane<C,B>, Raster, Raster.RasterAccessor, Raster.RasterProperty
- All Known Implementing Classes:
RasterImpl, RasterPropertyBuilder
public interface GridModeAccessor
Provides an accessor for a grid mode property.
-
Nested Class Summary
Nested ClassesModifier and TypeInterfaceDescriptionstatic interfaceProvides a builder method for a grid mode property returning the builder for applying multiple build operations.static interfaceProvides a mutator for a grid mode property.static interfaceProvides a grid mode property. -
Method Summary
Modifier and TypeMethodDescriptionRetrieves the grid mode from the grid mode property.
-
Method Details
-
getGridMode
GridMode getGridMode()Retrieves the grid mode from the grid mode property.- Returns:
- The grid mode stored by the grid mode property.
-