Interface GridModeAccessor.GridModeMutator
- All Known Subinterfaces:
GridModeAccessor.GridModeProperty, GridViewportPane<C,B>, Raster.RasterMutator, Raster.RasterProperty
- All Known Implementing Classes:
RasterPropertyBuilder
- Enclosing interface:
GridModeAccessor
public static interface GridModeAccessor.GridModeMutator
Provides a mutator for a grid mode property.
-
Method Summary
Modifier and TypeMethodDescriptionvoidsetGridMode(GridMode aGridMode) Sets the grid mode for the grid mode property.
-
Method Details
-
setGridMode
Sets the grid mode for the grid mode property.- Parameters:
aGridMode- The grid mode to be stored by the grid mode property.
-