Interface GridOffsetYAccessor
- All Known Subinterfaces:
GridOffset, GridOffset.GridOffsetAccessor, GridOffset.GridOffsetProperty, GridOffsetYAccessor.GridOffsetYProperty
public interface GridOffsetYAccessor
Provides an accessor for a Y offset property.
-
Nested Class Summary
Nested ClassesModifier and TypeInterfaceDescriptionstatic interfaceProvides a builder method for a Y offset property returning the builder for applying multiple build operations.static interfaceProvides a mutator for a Y offset property.static interfaceProvides a Y offset property. -
Method Summary
Modifier and TypeMethodDescriptionintRetrieves the Y offset from the Y offset property.
-
Method Details
-
getGridOffsetY
int getGridOffsetY()Retrieves the Y offset from the Y offset property.- Returns:
- The Y offset stored by the Y offset property.
-