Interface GridWidthAccessor
- All Known Subinterfaces:
GridDimension, GridDimension.GridDimensionAccessor, GridDimension.GridDimensionProperty, GridWidthAccessor.GridWidthProperty, Raster, Raster.RasterAccessor, Raster.RasterProperty
- All Known Implementing Classes:
GridDimensionImpl, RasterImpl, RasterPropertyBuilder
public interface GridWidthAccessor
Provides an accessor for a grid width property.
-
Nested Class Summary
Nested ClassesModifier and TypeInterfaceDescriptionstatic interfaceProvides a builder method for a grid width property returning the builder for applying multiple build operations.static interfaceProvides a mutator for a grid width property.static interfaceProvides a grid width property. -
Method Summary
Modifier and TypeMethodDescriptionintRetrieves the grid width from the grid width property.
-
Method Details
-
getGridWidth
int getGridWidth()Retrieves the grid width from the grid width property.- Returns:
- The grid width stored by the grid width property.
-