Interface GridWidthAccessor.GridWidthMutator
- All Known Subinterfaces:
GridDimension.GridDimensionMutator, GridDimension.GridDimensionProperty, GridWidthAccessor.GridWidthProperty, Raster.RasterMutator, Raster.RasterProperty
- All Known Implementing Classes:
RasterPropertyBuilder
- Enclosing interface:
GridWidthAccessor
public static interface GridWidthAccessor.GridWidthMutator
Provides a mutator for a grid width property.
-
Method Summary
Modifier and TypeMethodDescriptionvoidsetGridWidth(int aWidth) Sets the grid width for the grid width property.
-
Method Details
-
setGridWidth
void setGridWidth(int aWidth) Sets the grid width for the grid width property.- Parameters:
aWidth- The grid width to be stored by the grid width property.
-