Interface LayoutModeAccessor.LayoutModeBuilder<B extends LayoutModeAccessor.LayoutModeBuilder<B>>
- Type Parameters:
B- The builder to return in order to be able to apply multiple build operations.
- Enclosing interface:
LayoutModeAccessor
public static interface LayoutModeAccessor.LayoutModeBuilder<B extends LayoutModeAccessor.LayoutModeBuilder<B>>
Provides a builder method for a layout mode property returning the
builder for applying multiple build operations.
-
Method Summary
Modifier and TypeMethodDescriptionwithLayoutMode(LayoutMode aLayoutMode) Sets the layout mode for the layout mode property.
-
Method Details
-
withLayoutMode
Sets the layout mode for the layout mode property.- Parameters:
aLayoutMode- The layout mode to be stored by the font style property.- Returns:
- The builder for applying multiple build operations.
-