Interface LeftPaddingAccessor
- All Known Subinterfaces:
LeftPaddingAccessor.LeftPaddingProperty, Padding, Padding.PaddingAccessor, Padding.PaddingProperty
public interface LeftPaddingAccessor
Provides an accessor for a left padding property.
-
Nested Class Summary
Nested ClassesModifier and TypeInterfaceDescriptionstatic interfaceProvides a builder method for a left padding property returning the builder for applying multiple build operations.static interfaceProvides a mutator for a left padding property.static interfaceProvides a left padding property. -
Method Summary
Modifier and TypeMethodDescriptionintRetrieves the left padding from the left padding property.
-
Method Details
-
getLeftPadding
int getLeftPadding()Retrieves the left padding from the left padding property.- Returns:
- The left padding stored by the left padding property.
-