Interface MoveModeAccessor
- All Known Subinterfaces:
GridViewportPane<C,,B> MoveModeAccessor.MoveModeProperty
public interface MoveModeAccessor
Provides an accessor for a move mode property.
-
Nested Class Summary
Nested ClassesModifier and TypeInterfaceDescriptionstatic interfaceProvides a builder method for a move mode property returning the builder for applying multiple build operations.static interfaceProvides a mutator for a move mode property.static interfaceProvides a move mode property. -
Method Summary
Modifier and TypeMethodDescriptionRetrieves the move mode from the move mode property.
-
Method Details
-
getMoveMode
MoveMode getMoveMode()Retrieves the move mode from the move mode property.- Returns:
- The move mode stored by the move mode property.
-