Interface MoveModeAccessor.MoveModeMutator
- All Known Subinterfaces:
GridViewportPane<C,B>, MoveModeAccessor.MoveModeProperty
- Enclosing interface:
MoveModeAccessor
public static interface MoveModeAccessor.MoveModeMutator
Provides a mutator for a move mode property.
-
Method Summary
Modifier and TypeMethodDescriptionvoidsetMoveMode(MoveMode aMoveMode) Sets the move mode for the move mode property.
-
Method Details
-
setMoveMode
Sets the move mode for the move mode property.- Parameters:
aMoveMode- The move mode to be stored by the move mode property.
-