Interface PixGridBannerPanel
- All Superinterfaces:
org.refcodes.mixin.Clearable,PixGridPane,VisibleAccessor,VisibleAccessor.VisibleMutator,VisibleAccessor.VisibleProperty
The
PixGridBannerPanel extends the PixGridPane and manages a
RgbPixmap to be painted on a grid panel (such as an LED matrix) and
moved or faded over that grid panel. The panel is divided into pixels of a
defined x and y position, a defined size and defined PixelShape. The
underlying RgbPixmap is projected onto that grid pane by applying any
of the various operations.-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.graphical.VisibleAccessor
VisibleAccessor.VisibleBuilder<B extends VisibleAccessor.VisibleBuilder<B>>, VisibleAccessor.VisibleMutator, VisibleAccessor.VisibleProperty -
Method Summary
Modifier and TypeMethodDescriptionvoidmoveEast(int aSteps, int aStartDelayMillis, int aEndDelayMillis) Move theRgbPixmapto the east.voidmoveNorth(int aSteps, int aStartDelayMillis, int aEndDelayMillis) Move theRgbPixmapto the north.voidmoveNorthEast(int aSteps, int aStartDelayMillis, int aEndDelayMillis) Move theRgbPixmapto the north east.voidmoveNorthWest(int aSteps, int aStartDelayMillis, int aEndDelayMillis) Move theRgbPixmapto the north west.voidmoveSouth(int aSteps, int aStartDelayMillis, int aEndDelayMillis) Move theRgbPixmapto the south.voidmoveSouthEast(int aSteps, int aStartDelayMillis, int aEndDelayMillis) Move theRgbPixmapto the south east.voidmoveSouthWest(int aSteps, int aStartDelayMillis, int aEndDelayMillis) Move theRgbPixmapto the south west.voidmoveWest(int aSteps, int aStartDelayMillis, int aEndDelayMillis) Move theRgbPixmapto the west.voidrndFadeToPixmap(RgbPixmap.RgbPixmapBuilder aFadeToPixmap, int aOffsetX, int aOffsetY, float aPixelPropability, int aPixelDelayMillis) Rnd fade to pixmap.voidstepFadeToPixmap(RgbPixmap.RgbPixmapBuilder aFadeToPixmap, int aOffsetX, int aOffsetY, int aStepWidth, int aPixelDelayMillis) Step fade to pixmap.Methods inherited from interface org.refcodes.mixin.Clearable
clearMethods inherited from interface org.refcodes.graphical.PixGridPane
addBlankArea, addBlankArea, clearBlankAreas, getBottomBorder, getHorizontalSpace, getInactivePixelColor, getLeftBorder, getMatrixDrawingHeight, getMatrixDrawingHeight, getMatrixDrawingWidth, getMatrixDrawingWidth, getMatrixHeight, getMatrixSize, getMatrixWidth, getPixelAt, getPixelHeight, getPixelShape, getPixelWidth, getPixmapOffsetX, getPixmapOffsetY, getPixmapSnapshot, getRgbPixmap, getRightBorder, getTopBorder, getVerticalSpace, isHorizontalWrapEnabled, isVerticalWrapEnabled, removeBlankArea, repaint, setPixelAtAt, setPixmapOffsetMethods inherited from interface org.refcodes.graphical.VisibleAccessor
isVisibleMethods inherited from interface org.refcodes.graphical.VisibleAccessor.VisibleMutator
hide, setVisible, showMethods inherited from interface org.refcodes.graphical.VisibleAccessor.VisibleProperty
letVisible
-
Method Details
-
moveNorth
void moveNorth(int aSteps, int aStartDelayMillis, int aEndDelayMillis) Move theRgbPixmapto the north.- Parameters:
aSteps- the a stepsaStartDelayMillis- the a start delay in millisecondsaEndDelayMillis- the a end delay in milliseconds
-
moveNorthEast
void moveNorthEast(int aSteps, int aStartDelayMillis, int aEndDelayMillis) Move theRgbPixmapto the north east.- Parameters:
aSteps- the a stepsaStartDelayMillis- the a start delay in millisecondsaEndDelayMillis- the a end delay in milliseconds
-
moveEast
void moveEast(int aSteps, int aStartDelayMillis, int aEndDelayMillis) Move theRgbPixmapto the east.- Parameters:
aSteps- the a stepsaStartDelayMillis- the a start delay in millisecondsaEndDelayMillis- the a end delay in milliseconds
-
moveSouthEast
void moveSouthEast(int aSteps, int aStartDelayMillis, int aEndDelayMillis) Move theRgbPixmapto the south east.- Parameters:
aSteps- the a stepsaStartDelayMillis- the a start delay in millisecondsaEndDelayMillis- the a end delay in milliseconds
-
moveSouth
void moveSouth(int aSteps, int aStartDelayMillis, int aEndDelayMillis) Move theRgbPixmapto the south.- Parameters:
aSteps- the a stepsaStartDelayMillis- the a start delay in millisecondsaEndDelayMillis- the a end delay in milliseconds
-
moveSouthWest
void moveSouthWest(int aSteps, int aStartDelayMillis, int aEndDelayMillis) Move theRgbPixmapto the south west.- Parameters:
aSteps- the a stepsaStartDelayMillis- the a start delay in millisecondsaEndDelayMillis- the a end delay in milliseconds
-
moveWest
void moveWest(int aSteps, int aStartDelayMillis, int aEndDelayMillis) Move theRgbPixmapto the west.- Parameters:
aSteps- the a stepsaStartDelayMillis- the a start delay in millisecondsaEndDelayMillis- the a end delay in milliseconds
-
moveNorthWest
void moveNorthWest(int aSteps, int aStartDelayMillis, int aEndDelayMillis) Move theRgbPixmapto the north west.- Parameters:
aSteps- the a stepsaStartDelayMillis- the a start delay in millisecondsaEndDelayMillis- the a end delay in milliseconds
-
stepFadeToPixmap
void stepFadeToPixmap(RgbPixmap.RgbPixmapBuilder aFadeToPixmap, int aOffsetX, int aOffsetY, int aStepWidth, int aPixelDelayMillis) Step fade to pixmap.- Parameters:
aFadeToPixmap- the a fade to pixmapaOffsetX- the a offset XaOffsetY- the a offset YaStepWidth- the a step widthaPixelDelayMillis- the a pixel delay milliseconds
-
rndFadeToPixmap
void rndFadeToPixmap(RgbPixmap.RgbPixmapBuilder aFadeToPixmap, int aOffsetX, int aOffsetY, float aPixelPropability, int aPixelDelayMillis) Rnd fade to pixmap.- Parameters:
aFadeToPixmap- the a fade to pixmapaOffsetX- the a offset XaOffsetY- the a offset YaPixelPropability- the a pixel probabilityaPixelDelayMillis- the a pixel delay milliseconds
-