Interface PixGridPane
- All Superinterfaces:
Clearable, VisibleAccessor, VisibleAccessor.VisibleMutator, VisibleAccessor.VisibleProperty
- All Known Subinterfaces:
PixGridBannerPanel
The
PixGridPane projects a RgbPixmap on a grid panel (such as
an LED matrix) , the underlying RgbPixmap is painted onto that grid
pane as implemented by any implementing classes.-
Nested Class Summary
Nested classes/interfaces inherited from interface VisibleAccessor
VisibleAccessor.VisibleBuilder<B>, VisibleAccessor.VisibleMutator, VisibleAccessor.VisibleProperty -
Method Summary
Modifier and TypeMethodDescriptionbooleanaddBlankArea(int aPosX, int aPosY, int aWidth, int aHeight) Adds the blank area not to be painted with grid pixels.booleanaddBlankArea(Rectangle aArea) Adds the blank area not to be painted with grid pixels.voidRemoves all blank areas now to be painted with grid pixels again.intGets the bottom border.intGets the horizontal space.Gets the inactive pixel color.intGets the left border.default intGets the matrix drawing height.intgetMatrixDrawingHeight(boolean isWithBorder, boolean isWithPixelSpace, boolean isWithPixelHeight) Gets the matrix drawing height.default intGets the matrix drawing width.intgetMatrixDrawingWidth(boolean isWithBorder, boolean isWithPixelSpace, boolean isWithPixelWidth) Gets the matrix drawing width.intGets the matrix height.Gets the matrix size.intGets the matrix width.getPixelAt(int aPosX, int aPosY) Gets theRgbPixelat the given position.intGets the pixel height.Gets the pixel shape.intGets the pixel width.intGets the pixmap offset X.intGets the pixmap offset Y.Gets the pixmap snapshot.Gets the underlyingRgbPixmap.RgbPixmapBuilder.intGets the right border.intGets the top border.intGets the vertical space.booleanChecks if is horizontal wrap enabled.booleanChecks if is vertical wrap enabled.booleanremoveBlankArea(Rectangle aArea) Removes the blank area now to be painted with grid pixels again.voidrepaint()Repaint the pane with the underlying metrics and pixmap.voidsetPixelAtAt(RgbPixel aPixel, int aPosX, int aPosY) Paints theRgbPixelat the given position.voidsetPixmapOffset(int aPosX, int aPosY) Sets the pixmap offset.Methods inherited from interface VisibleAccessor
isHidden, isVisibleMethods inherited from interface VisibleAccessor.VisibleMutator
hide, setVisible, showMethods inherited from interface VisibleAccessor.VisibleProperty
letVisible
-
Method Details
-
getPixelAt
Gets theRgbPixelat the given position.- Parameters:
aPosX- the x positionaPosY- the y position- Returns:
- the
RgbPixelat the given position - Throws:
IndexOutOfBoundsException- the index out of bounds exception
-
setPixelAtAt
-
getTopBorder
int getTopBorder()Gets the top border.- Returns:
- the top border
-
getBottomBorder
int getBottomBorder()Gets the bottom border.- Returns:
- the bottom border
-
getLeftBorder
int getLeftBorder()Gets the left border.- Returns:
- the left border
-
getRightBorder
int getRightBorder()Gets the right border.- Returns:
- the right border
-
getHorizontalSpace
int getHorizontalSpace()Gets the horizontal space.- Returns:
- the horizontal space
-
getVerticalSpace
int getVerticalSpace()Gets the vertical space.- Returns:
- the vertical space
-
getPixelWidth
int getPixelWidth()Gets the pixel width.- Returns:
- the pixel width
-
getPixelHeight
int getPixelHeight()Gets the pixel height.- Returns:
- the pixel height
-
getPixelShape
-
getMatrixWidth
int getMatrixWidth()Gets the matrix width.- Returns:
- the matrix width
-
getMatrixHeight
int getMatrixHeight()Gets the matrix height.- Returns:
- the matrix height
-
getMatrixSize
-
getRgbPixmap
RgbPixmap.RgbPixmapBuilder getRgbPixmap()Gets the underlyingRgbPixmap.RgbPixmapBuilder.- Returns:
- the according
RgbPixmap.RgbPixmapBuilder.
-
getPixmapOffsetX
int getPixmapOffsetX()Gets the pixmap offset X.- Returns:
- the pixmap offset X
-
getPixmapOffsetY
int getPixmapOffsetY()Gets the pixmap offset Y.- Returns:
- the pixmap offset Y
-
isHorizontalWrapEnabled
boolean isHorizontalWrapEnabled()Checks if is horizontal wrap enabled.- Returns:
- true, if is horizontal wrap enabled
-
isVerticalWrapEnabled
boolean isVerticalWrapEnabled()Checks if is vertical wrap enabled.- Returns:
- true, if is vertical wrap enabled
-
getPixmapSnapshot
RgbPixmap.RgbPixmapBuilder getPixmapSnapshot()Gets the pixmap snapshot.- Returns:
- the pixmap snapshot
-
addBlankArea
boolean addBlankArea(int aPosX, int aPosY, int aWidth, int aHeight) Adds the blank area not to be painted with grid pixels.- Parameters:
aPosX- the x positionaPosY- the y positionaWidth- the according area's widthaHeight- the according area's height- Returns:
- true, if successfully added, false if such an area has already been added.
-
addBlankArea
-
removeBlankArea
-
clearBlankAreas
void clearBlankAreas()Removes all blank areas now to be painted with grid pixels again. -
getInactivePixelColor
-
getMatrixDrawingWidth
default int getMatrixDrawingWidth()Gets the matrix drawing width.- Returns:
- the matrix drawing width
-
getMatrixDrawingHeight
default int getMatrixDrawingHeight()Gets the matrix drawing height.- Returns:
- the matrix drawing height
-
getMatrixDrawingWidth
int getMatrixDrawingWidth(boolean isWithBorder, boolean isWithPixelSpace, boolean isWithPixelWidth) Gets the matrix drawing width.- Parameters:
isWithBorder- the is with borderisWithPixelSpace- the is with pixel spaceisWithPixelWidth- the is with pixel width- Returns:
- the matrix drawing width
-
getMatrixDrawingHeight
int getMatrixDrawingHeight(boolean isWithBorder, boolean isWithPixelSpace, boolean isWithPixelHeight) Gets the matrix drawing height.- Parameters:
isWithBorder- the is with borderisWithPixelSpace- the is with pixel spaceisWithPixelHeight- the is with pixel height- Returns:
- the matrix drawing height
-
setPixmapOffset
void setPixmapOffset(int aPosX, int aPosY) Sets the pixmap offset.- Parameters:
aPosX- the a X posaPosY- the a Y pos
-
repaint
void repaint()Repaint the pane with the underlying metrics and pixmap.
-