Interface PosXAccessor
- All Known Subinterfaces:
Position, Position.PositionProperty, PosXAccessor.PosXProperty, Rectangle, Rectangle.RectangleProperty
- All Known Implementing Classes:
PositionImpl, PositionPropertyBuilder, RectangleImpl
public interface PosXAccessor
Provides an accessor for a X position property.
-
Nested Class Summary
Nested ClassesModifier and TypeInterfaceDescriptionstatic interfacePosXAccessor.PosXBuilder<B extends PosXAccessor.PosXBuilder<B>>Provides a builder method for a X position property returning the builder for applying multiple build operations.static interfaceProvides a mutator for a X position property.static interfaceProvides a X position property. -
Method Summary
Modifier and TypeMethodDescriptionintRetrieves the X position from the X position property.
-
Method Details
-
getPositionX
int getPositionX()Retrieves the X position from the X position property.- Returns:
- The X position stored by the X position property.
-