Class PositionImpl
java.lang.Object
org.refcodes.graphical.PositionImpl
- All Implemented Interfaces:
Position, PosXAccessor, PosYAccessor
- Direct Known Subclasses:
PositionPropertyBuilder
The class
PositionImpl class implements the Position
interface.-
Nested Class Summary
Nested classes/interfaces inherited from interface Position
Position.PositionBuilder<B>, Position.PositionMutator, Position.PositionPropertyNested classes/interfaces inherited from interface PosXAccessor
PosXAccessor.PosXBuilder<B>, PosXAccessor.PosXMutator, PosXAccessor.PosXPropertyNested classes/interfaces inherited from interface PosYAccessor
PosYAccessor.PosYBuilder<B>, PosYAccessor.PosYMutator, PosYAccessor.PosYProperty -
Field Summary
Fields -
Constructor Summary
ConstructorsModifierConstructorDescriptionprotectedInstantiates a new position impl.PositionImpl(int aPosX, int aPosY) Instantiates a new position impl. -
Method Summary
-
Field Details
-
_posX
protected int _posX -
_posY
protected int _posY
-
-
Constructor Details
-
PositionImpl
protected PositionImpl()Instantiates a new position impl. -
PositionImpl
public PositionImpl(int aPosX, int aPosY) Instantiates a new position impl.- Parameters:
aPosX- the pos XaPosY- the pos Y
-
-
Method Details
-
getPositionX
public int getPositionX()Retrieves the X position from the X position property.- Specified by:
getPositionXin interfacePosXAccessor- Returns:
- The X position stored by the X position property.
-
getPositionY
public int getPositionY()Retrieves the Y position from the Y position property.- Specified by:
getPositionYin interfacePosYAccessor- Returns:
- The Y position stored by the Y position property.
-
toString
-
hashCode
-
equals
-