Class PositionPropertyBuilder
java.lang.Object
org.refcodes.graphical.PositionImpl
org.refcodes.graphical.PositionPropertyBuilder
- All Implemented Interfaces:
Position, Position.PositionBuilder<PositionPropertyBuilder>, Position.PositionMutator, Position.PositionProperty, PosXAccessor, PosXAccessor.PosXBuilder<PositionPropertyBuilder>, PosXAccessor.PosXMutator, PosXAccessor.PosXProperty, PosYAccessor, PosYAccessor.PosYBuilder<PositionPropertyBuilder>, PosYAccessor.PosYMutator, PosYAccessor.PosYProperty
public class PositionPropertyBuilder
extends PositionImpl
implements Position.PositionProperty, Position.PositionBuilder<PositionPropertyBuilder>
The Class PositionPropertyBuilder.
-
Nested Class Summary
Nested classes/interfaces inherited from interface Position
Position.PositionBuilder<B>, Position.PositionMutator, Position.PositionPropertyNested classes/interfaces inherited from interface PosXAccessor
PosXAccessor.PosXBuilder<B>, PosXAccessor.PosXMutator, PosXAccessor.PosXPropertyNested classes/interfaces inherited from interface PosYAccessor
PosYAccessor.PosYBuilder<B>, PosYAccessor.PosYMutator, PosYAccessor.PosYProperty -
Field Summary
Fields inherited from class PositionImpl
_posX, _posY -
Constructor Summary
ConstructorsConstructorDescriptionInstantiates a new position property builder impl.PositionPropertyBuilder(int aPosX, int aPosY) Instantiates a new position property builder impl. -
Method Summary
Modifier and TypeMethodDescriptionvoidsetPosition(int aPosX, int aPosY) Sets the position.voidsetPosition(Position aPosition) Sets the position.voidsetPositionX(int aPosX) Sets the X position for the X position property.voidsetPositionY(int aPosY) Sets the Y position for the Y position property.withPosition(int aPosX, int aPosY) With position.withPosition(Position aPosition) With position.withPositionX(int aPosX) Sets the X position for the X position property.withPositionY(int aPosY) Sets the Y position for the Y position property.Methods inherited from class PositionImpl
equals, getPositionX, getPositionY, hashCode, toStringMethods inherited from interface Position.PositionProperty
addTo, letPosition, letPosition, subFromMethods inherited from interface PosXAccessor
getPositionXMethods inherited from interface PosXAccessor.PosXProperty
letPositionXMethods inherited from interface PosYAccessor
getPositionYMethods inherited from interface PosYAccessor.PosYProperty
letPositionY
-
Constructor Details
-
PositionPropertyBuilder
public PositionPropertyBuilder()Instantiates a new position property builder impl. -
PositionPropertyBuilder
public PositionPropertyBuilder(int aPosX, int aPosY) Instantiates a new position property builder impl.- Parameters:
aPosX- the pos XaPosY- the pos Y
-
-
Method Details
-
setPositionX
public void setPositionX(int aPosX) Sets the X position for the X position property.- Specified by:
setPositionXin interfacePosXAccessor.PosXMutator- Parameters:
aPosX- The X position to be stored by the X position property.
-
withPositionX
Sets the X position for the X position property.- Specified by:
withPositionXin interfacePosXAccessor.PosXBuilder<PositionPropertyBuilder>- Parameters:
aPosX- The X position to be stored by the X position property.- Returns:
- The builder for applying multiple build operations.
-
setPositionY
public void setPositionY(int aPosY) Sets the Y position for the Y position property.- Specified by:
setPositionYin interfacePosYAccessor.PosYMutator- Parameters:
aPosY- The Y position to be stored by the Y position property.
-
withPositionY
Sets the Y position for the Y position property.- Specified by:
withPositionYin interfacePosYAccessor.PosYBuilder<PositionPropertyBuilder>- Parameters:
aPosY- The Y position to be stored by the Y position property.- Returns:
- The builder for applying multiple build operations.
-
withPosition
With position.- Specified by:
withPositionin interfacePosition.PositionBuilder<PositionPropertyBuilder>- Parameters:
aPosX- the pos XaPosY- the pos Y- Returns:
- the b
-
withPosition
With position.- Specified by:
withPositionin interfacePosition.PositionBuilder<PositionPropertyBuilder>- Parameters:
aPosition- the position- Returns:
- the b
-
setPosition
public void setPosition(int aPosX, int aPosY) Sets the position.- Specified by:
setPositionin interfacePosition.PositionMutator- Parameters:
aPosX- the pos XaPosY- the pos Y
-
setPosition
Sets the position.- Specified by:
setPositionin interfacePosition.PositionMutator- Parameters:
aPosition- the new position
-