Class RasterImpl
java.lang.Object
org.refcodes.graphical.RasterImpl
- All Implemented Interfaces:
FieldDimension, FieldGapAccessor, FieldHeightAccessor, FieldWidthAccessor, GridDimension, GridHeightAccessor, GridModeAccessor, GridWidthAccessor, Raster
- Direct Known Subclasses:
RasterPropertyBuilder
-
Nested Class Summary
Nested classes/interfaces inherited from interface FieldDimension
FieldDimension.FieldDimensionAccessor, FieldDimension.FieldDimensionBuilder<B>, FieldDimension.FieldDimensionMutator, FieldDimension.FieldDimensionPropertyNested classes/interfaces inherited from interface FieldGapAccessor
FieldGapAccessor.FieldGapBuilder<B>, FieldGapAccessor.FieldGapMutator, FieldGapAccessor.FieldGapPropertyNested classes/interfaces inherited from interface FieldHeightAccessor
FieldHeightAccessor.FieldHeightBuilder<B>, FieldHeightAccessor.FieldHeightMutator, FieldHeightAccessor.FieldHeightPropertyNested classes/interfaces inherited from interface FieldWidthAccessor
FieldWidthAccessor.FieldWidthBuilder<B>, FieldWidthAccessor.FieldWidthMutator, FieldWidthAccessor.FieldWidthPropertyNested classes/interfaces inherited from interface GridDimension
GridDimension.GridDimensionAccessor, GridDimension.GridDimensionBuilder<B>, GridDimension.GridDimensionMutator, GridDimension.GridDimensionPropertyNested classes/interfaces inherited from interface GridHeightAccessor
GridHeightAccessor.GridHeightBuilder<B>, GridHeightAccessor.GridHeightMutator, GridHeightAccessor.GridHeightPropertyNested classes/interfaces inherited from interface GridModeAccessor
GridModeAccessor.GridModeBuilder<B>, GridModeAccessor.GridModeMutator, GridModeAccessor.GridModePropertyNested classes/interfaces inherited from interface GridWidthAccessor
GridWidthAccessor.GridWidthBuilder<B>, GridWidthAccessor.GridWidthMutator, GridWidthAccessor.GridWidthPropertyNested classes/interfaces inherited from interface Raster
Raster.RasterAccessor, Raster.RasterBuilder<B>, Raster.RasterMutator, Raster.RasterProperty -
Field Summary
FieldsModifier and TypeFieldDescriptionprotected intprotected intprotected intprotected intprotected GridModeprotected int -
Constructor Summary
ConstructorsModifierConstructorDescriptionprotectedInstantiates a new raster impl.RasterImpl(int aGridWidth, int aGridHeight, int aWidth, int aHeight, int aGap, GridMode aGridMode) Instantiates a new raster impl. -
Method Summary
Modifier and TypeMethodDescriptionintRetrieves the field gap from the field gap property.intRetrieves the field height from the field height property.intRetrieves the field width from the field width property.intRetrieves the grid height from the grid height property.Retrieves the grid mode from the grid mode property.intRetrieves the grid width from the grid width property.Methods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, waitMethods inherited from interface GridDimension
isInBounds, isInBounds, isInHeight, isInWidth
-
Field Details
-
_gridWidth
protected int _gridWidth -
_gridHeight
protected int _gridHeight -
_fieldHeight
protected int _fieldHeight -
_fieldWidth
protected int _fieldWidth -
_fieldGap
protected int _fieldGap -
_gridMode
-
-
Constructor Details
-
RasterImpl
protected RasterImpl()Instantiates a new raster impl. -
RasterImpl
public RasterImpl(int aGridWidth, int aGridHeight, int aWidth, int aHeight, int aGap, GridMode aGridMode) Instantiates a new raster impl.- Parameters:
aGridWidth- the grid widthaGridHeight- the grid heightaWidth- the widthaHeight- the heightaGap- the gapaGridMode- the grid mode
-
-
Method Details
-
getGridWidth
public int getGridWidth()Retrieves the grid width from the grid width property.- Specified by:
getGridWidthin interfaceGridWidthAccessor- Returns:
- The grid width stored by the grid width property.
-
getGridMode
Retrieves the grid mode from the grid mode property.- Specified by:
getGridModein interfaceGridModeAccessor- Returns:
- The grid mode stored by the grid mode property.
-
getFieldGap
public int getFieldGap()Retrieves the field gap from the field gap property.- Specified by:
getFieldGapin interfaceFieldGapAccessor- Returns:
- The field gap stored by the field gap property.
-
getFieldWidth
public int getFieldWidth()Retrieves the field width from the field width property.- Specified by:
getFieldWidthin interfaceFieldWidthAccessor- Returns:
- The field width stored by the field width property.
-
getFieldHeight
public int getFieldHeight()Retrieves the field height from the field height property.- Specified by:
getFieldHeightin interfaceFieldHeightAccessor- Returns:
- The field height stored by the field height property.
-
getGridHeight
public int getGridHeight()Retrieves the grid height from the grid height property.- Specified by:
getGridHeightin interfaceGridHeightAccessor- Returns:
- The grid height stored by the grid height property.
-