Interface Rectangle.RectangleProperty
- All Superinterfaces:
Dimension, Dimension.DimensionAccessor, Dimension.DimensionMutator, Dimension.DimensionProperty, HeightAccessor, HeightAccessor.HeightMutator, HeightAccessor.HeightProperty, Position, Position.PositionMutator, Position.PositionProperty, PosXAccessor, PosXAccessor.PosXMutator, PosXAccessor.PosXProperty, PosYAccessor, PosYAccessor.PosYMutator, PosYAccessor.PosYProperty, Rectangle, Rectangle.RectangleMutator, WidthAccessor, WidthAccessor.WidthMutator, WidthAccessor.WidthProperty
- Enclosing interface:
Rectangle
public static interface Rectangle.RectangleProperty
extends Rectangle, Rectangle.RectangleMutator, Dimension.DimensionProperty, Position.PositionProperty
Provides a property (getter / setter) for a rectangle property (dimension
and height).
-
Nested Class Summary
Nested classes/interfaces inherited from interface Dimension
Dimension.DimensionAccessor, Dimension.DimensionBuilder<B>, Dimension.DimensionMutator, Dimension.DimensionPropertyNested classes/interfaces inherited from interface HeightAccessor
HeightAccessor.HeightBuilder<B>, HeightAccessor.HeightMutator, HeightAccessor.HeightPropertyNested classes/interfaces inherited from interface Position
Position.PositionBuilder<B>, Position.PositionMutator, Position.PositionPropertyNested classes/interfaces inherited from interface PosXAccessor
PosXAccessor.PosXBuilder<B>, PosXAccessor.PosXMutator, PosXAccessor.PosXPropertyNested classes/interfaces inherited from interface PosYAccessor
PosYAccessor.PosYBuilder<B>, PosYAccessor.PosYMutator, PosYAccessor.PosYPropertyNested classes/interfaces inherited from interface Rectangle
Rectangle.RectangleBuilder<B>, Rectangle.RectangleMutator, Rectangle.RectanglePropertyNested classes/interfaces inherited from interface WidthAccessor
WidthAccessor.WidthBuilder<B>, WidthAccessor.WidthMutator, WidthAccessor.WidthProperty -
Method Summary
Modifier and TypeMethodDescriptiondefault RectangleletRectangle(int aPositionX, int aPositionY, int aWidth, int aHeight) This method stores and passes through the given arguments, which is very useful for builder APIs: Sets the givenRectangle(setter) as ofRectangle.RectangleMutator.setRectangle(int, int, int, int)and returns the very same value encapsulated asRectangleinstance.default RectangleletRectangle(Rectangle aRectangle) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenRectangle(setter) as ofRectangle.RectangleMutator.setRectangle(Rectangle)and returns the very same value (getter).Methods inherited from interface Dimension.DimensionMutator
setDimension, setDimensionMethods inherited from interface Dimension.DimensionProperty
letDimension, letDimensionMethods inherited from interface HeightAccessor
getHeightMethods inherited from interface HeightAccessor.HeightMutator
setHeightMethods inherited from interface HeightAccessor.HeightProperty
letHeightMethods inherited from interface Position.PositionMutator
setPosition, setPositionMethods inherited from interface Position.PositionProperty
addTo, letPosition, letPosition, subFromMethods inherited from interface PosXAccessor
getPositionXMethods inherited from interface PosXAccessor.PosXMutator
setPositionXMethods inherited from interface PosXAccessor.PosXProperty
letPositionXMethods inherited from interface PosYAccessor
getPositionYMethods inherited from interface PosYAccessor.PosYMutator
setPositionYMethods inherited from interface PosYAccessor.PosYProperty
letPositionYMethods inherited from interface Rectangle.RectangleMutator
setRectangle, setRectangleMethods inherited from interface WidthAccessor
getWidthMethods inherited from interface WidthAccessor.WidthMutator
setWidthMethods inherited from interface WidthAccessor.WidthProperty
letWidth
-
Method Details
-
letRectangle
This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenRectangle(setter) as ofRectangle.RectangleMutator.setRectangle(Rectangle)and returns the very same value (getter).- Parameters:
aRectangle- The new rectangle's metrics to set (viaRectangle.RectangleMutator.setRectangle(Rectangle)).- Returns:
- Returns the value passed for it to be used in conclusive processing steps.
-
letRectangle
This method stores and passes through the given arguments, which is very useful for builder APIs: Sets the givenRectangle(setter) as ofRectangle.RectangleMutator.setRectangle(int, int, int, int)and returns the very same value encapsulated asRectangleinstance.- Parameters:
aPositionX- The X position of the rectangle.aPositionY- The Y position of the rectangle.aWidth- The width of the rectangle.aHeight- The height of the rectangle.- Returns:
- Returns the values passed encapsulated in a
Rectangleobject for it to be used in conclusive processing steps.
-