Interface RightPaddingAccessor.RightPaddingBuilder<B extends RightPaddingAccessor.RightPaddingBuilder<B>>
- Type Parameters:
B- The builder to return in order to be able to apply multiple build operations.
- All Known Subinterfaces:
Padding.PaddingBuilder<B>
- Enclosing interface:
RightPaddingAccessor
public static interface RightPaddingAccessor.RightPaddingBuilder<B extends RightPaddingAccessor.RightPaddingBuilder<B>>
Provides a builder method for a right padding property returning the
builder for applying multiple build operations.
-
Method Summary
Modifier and TypeMethodDescriptionwithRightPadding(int aRightPadding) Sets the right padding for the right padding property.
-
Method Details
-
withRightPadding
Sets the right padding for the right padding property.- Parameters:
aRightPadding- The right padding to be stored by the right padding property.- Returns:
- The builder for applying multiple build operations.
-