Interface RightPaddingAccessor.RightPaddingMutator
- All Known Subinterfaces:
Padding.PaddingMutator, Padding.PaddingProperty, RightPaddingAccessor.RightPaddingProperty
- Enclosing interface:
RightPaddingAccessor
public static interface RightPaddingAccessor.RightPaddingMutator
Provides a mutator for a right padding property.
-
Method Summary
Modifier and TypeMethodDescriptionvoidsetRightPadding(int aRightPadding) Sets the right padding for the right padding property.
-
Method Details
-
setRightPadding
void setRightPadding(int aRightPadding) Sets the right padding for the right padding property.- Parameters:
aRightPadding- The right padding to be stored by the right padding property.
-