Interface RightPaddingAccessor.RightPaddingProperty
- All Superinterfaces:
RightPaddingAccessor, RightPaddingAccessor.RightPaddingMutator
- All Known Subinterfaces:
Padding.PaddingProperty
- Enclosing interface:
RightPaddingAccessor
public static interface RightPaddingAccessor.RightPaddingProperty
extends RightPaddingAccessor, RightPaddingAccessor.RightPaddingMutator
Provides a right padding property.
-
Nested Class Summary
Nested classes/interfaces inherited from interface RightPaddingAccessor
RightPaddingAccessor.RightPaddingBuilder<B>, RightPaddingAccessor.RightPaddingMutator, RightPaddingAccessor.RightPaddingProperty -
Method Summary
Modifier and TypeMethodDescriptiondefault intletRightPadding(int aRightPadding) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the given integer (setter) as ofRightPaddingAccessor.RightPaddingMutator.setRightPadding(int)and returns the very same value (getter).Methods inherited from interface RightPaddingAccessor
getRightPaddingMethods inherited from interface RightPaddingAccessor.RightPaddingMutator
setRightPadding
-
Method Details
-
letRightPadding
default int letRightPadding(int aRightPadding) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the given integer (setter) as ofRightPaddingAccessor.RightPaddingMutator.setRightPadding(int)and returns the very same value (getter).- Parameters:
aRightPadding- The integer to set (viaRightPaddingAccessor.RightPaddingMutator.setRightPadding(int)).- Returns:
- Returns the value passed for it to be used in conclusive processing steps.
-