Interface TopPaddingAccessor
- All Known Subinterfaces:
Padding, Padding.PaddingAccessor, Padding.PaddingProperty, TopPaddingAccessor.TopPaddingProperty
public interface TopPaddingAccessor
Provides an accessor for a top padding property.
-
Nested Class Summary
Nested ClassesModifier and TypeInterfaceDescriptionstatic interfaceProvides a builder method for a top padding property returning the builder for applying multiple build operations.static interfaceProvides a mutator for a top padding property.static interfaceProvides a top padding property. -
Method Summary
Modifier and TypeMethodDescriptionintRetrieves the top padding from the top padding property.
-
Method Details
-
getTopPadding
int getTopPadding()Retrieves the top padding from the top padding property.- Returns:
- The top padding stored by the top padding property.
-