Interface TopPaddingAccessor.TopPaddingBuilder<B extends TopPaddingAccessor.TopPaddingBuilder<B>>
- Type Parameters:
B- The builder to return in order to be able to apply multiple build operations.
- All Known Subinterfaces:
Padding.PaddingBuilder<B>
- Enclosing interface:
TopPaddingAccessor
public static interface TopPaddingAccessor.TopPaddingBuilder<B extends TopPaddingAccessor.TopPaddingBuilder<B>>
Provides a builder method for a top padding property returning the
builder for applying multiple build operations.
-
Method Summary
Modifier and TypeMethodDescriptionwithTopPadding(int aTopPadding) Sets the top padding for the top padding property.
-
Method Details
-
withTopPadding
Sets the top padding for the top padding property.- Parameters:
aTopPadding- The top padding to be stored by the top padding property.- Returns:
- The builder for applying multiple build operations.
-