-
- All Superinterfaces:
VectorXAccessor,VectorYAccessor
- All Known Subinterfaces:
Vector.VectorProperty
public interface Vector extends VectorXAccessor, VectorYAccessor
Provides an accessor for a Y vector property.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceVector.VectorBuilder<B extends Vector.VectorBuilder<B>>The Interface VectorBuilder.static interfaceVector.VectorMutatorThe Interface VectorMutator.static interfaceVector.VectorPropertyThe Interface VectorProperty.-
Nested classes/interfaces inherited from interface org.refcodes.graphical.VectorXAccessor
VectorXAccessor.VectorXBuilder<B extends VectorXAccessor.VectorXBuilder<B>>, VectorXAccessor.VectorXMutator, VectorXAccessor.VectorXProperty
-
Nested classes/interfaces inherited from interface org.refcodes.graphical.VectorYAccessor
VectorYAccessor.VectorYBuilder<B extends VectorYAccessor.VectorYBuilder<B>>, VectorYAccessor.VectorYMutator, VectorYAccessor.VectorYProperty
-
-
Method Summary
Static Methods Modifier and Type Method Description static booleanequals(Vector aVectorA, Vector aVectorB)Equals.-
Methods inherited from interface org.refcodes.graphical.VectorXAccessor
getVectorX
-
Methods inherited from interface org.refcodes.graphical.VectorYAccessor
getVectorY
-
-