- All Known Subinterfaces:
Vector,Vector.VectorAccessor,Vector.VectorProperty,VectorXAccessor.VectorXProperty
public interface VectorXAccessor
Provides an accessor for a X vector property.
-
Nested Class Summary
Nested ClassesModifier and TypeInterfaceDescriptionstatic interfaceProvides a builder method for a X vector property returning the builder for applying multiple build operations.static interfaceProvides a mutator for a X vector property.static interfaceProvides a X vector property. -
Method Summary
Modifier and TypeMethodDescriptionintRetrieves the X vector from the X vector property.
-
Method Details
-
getVectorX
int getVectorX()Retrieves the X vector from the X vector property.- Returns:
- The X vector stored by the X vector property.
-