Interface VectorYAccessor
- All Known Subinterfaces:
Vector, Vector.VectorAccessor, Vector.VectorProperty, VectorYAccessor.VectorYProperty
public interface VectorYAccessor
Provides an accessor for a Y vector property.
-
Nested Class Summary
Nested ClassesModifier and TypeInterfaceDescriptionstatic interfaceProvides a builder method for a Y vector property returning the builder for applying multiple build operations.static interfaceProvides a mutator for a Y vector property.static interfaceProvides a Y vector property. -
Method Summary
Modifier and TypeMethodDescriptionintRetrieves the Y vector from the Y vector property.
-
Method Details
-
getVectorY
int getVectorY()Retrieves the Y vector from the Y vector property.- Returns:
- The Y vector stored by the Y vector property.
-