Uses of Interface
org.refcodes.graphical.BottomPaddingAccessor.BottomPaddingBuilder
-
Uses of BottomPaddingAccessor.BottomPaddingBuilder in org.refcodes.graphical
Classes in org.refcodes.graphical with type parameters of type BottomPaddingAccessor.BottomPaddingBuilderModifier and TypeInterfaceDescriptionstatic interfaceProvides a builder method for a bottom padding property returning the builder for applying multiple build operations.Subinterfaces of BottomPaddingAccessor.BottomPaddingBuilder in org.refcodes.graphicalModifier and TypeInterfaceDescriptionstatic interfacePadding.PaddingBuilder<B extends Padding.PaddingBuilder<B>>The Interface PaddingBuilder.