Uses of Enum Class
org.refcodes.graphical.GridMode
-
Uses of GridMode in org.refcodes.graphical
Subclasses with type arguments of type GridMode in org.refcodes.graphicalFields in org.refcodes.graphical declared as GridModeMethods in org.refcodes.graphical that return GridModeModifier and TypeMethodDescriptionGridModeAccessor.getGridMode()Retrieves the grid mode from the grid mode property.RasterImpl.getGridMode()Retrieves the grid mode from the grid mode property.default GridModeGridModeAccessor.GridModeProperty.letGridMode(GridMode aGridMode) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenGridMode(setter) as ofGridModeAccessor.GridModeMutator.setGridMode(GridMode)and returns the very same value (getter).static GridModeReturns the enum constant of this class with the specified name.static GridMode[]GridMode.values()Returns an array containing the constants of this enum class, in the order they are declared.Methods in org.refcodes.graphical with parameters of type GridModeModifier and TypeMethodDescriptiondefault GridModeGridModeAccessor.GridModeProperty.letGridMode(GridMode aGridMode) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenGridMode(setter) as ofGridModeAccessor.GridModeMutator.setGridMode(GridMode)and returns the very same value (getter).voidGridModeAccessor.GridModeMutator.setGridMode(GridMode aGridMode) Sets the grid mode for the grid mode property.voidRasterPropertyBuilder.setGridMode(GridMode aGridMode) Sets the grid mode for the grid mode property.GridModeAccessor.GridModeBuilder.withGridMode(GridMode aGridMode) Sets the grid mode for the grid mode property.RasterPropertyBuilder.withGridMode(GridMode aGridMode) Sets the grid mode for the grid mode property.Constructors in org.refcodes.graphical with parameters of type GridModeModifierConstructorDescriptionRasterImpl(int aGridWidth, int aGridHeight, int aWidth, int aHeight, int aGap, GridMode aGridMode) Instantiates a new raster impl.RasterPropertyBuilder(int aGridWidth, int aGridHeight, int aWidth, int aHeight, int aGap, GridMode aGridMode) Instantiates a new raster property builder impl.