Uses of Interface
org.refcodes.graphical.GridModeAccessor
-
Uses of GridModeAccessor in org.refcodes.graphical
Subinterfaces of GridModeAccessor in org.refcodes.graphicalModifier and TypeInterfaceDescriptionstatic interfaceProvides a grid mode property.interfaceGridViewportPane<C, B extends GridViewportPane<C,B>> The interfaceGridViewportPanedescribes the functionality of a graphical viewport onto a grid (such as a checkerboard): Just the viewport portion of a (larger) grid is displayed according to the settings of thisGridViewportPane.interfaceTheRasterdefines properties describing a matrix or a checkerboard.static interfacestatic interfaceClasses in org.refcodes.graphical that implement GridModeAccessorModifier and TypeClassDescriptionclassThe Class RasterImpl.classThe Class RasterPropertyBuilder.