Uses of Interface
org.refcodes.graphical.GridModeAccessor.GridModeProperty
-
Uses of GridModeAccessor.GridModeProperty in org.refcodes.graphical
Subinterfaces of GridModeAccessor.GridModeProperty in org.refcodes.graphicalModifier and TypeInterfaceDescriptioninterfaceGridViewportPane<C, B extends GridViewportPane<C,B>> The interfaceGridViewportPanedescribes the functionality of a graphical viewport onto a grid (such as a checkerboard): Just the viewport portion of a (larger) grid is displayed according to the settings of thisGridViewportPane.static interfaceClasses in org.refcodes.graphical that implement GridModeAccessor.GridModeProperty