Uses of Interface
org.refcodes.graphical.GridOffset
-
Uses of GridOffset in org.refcodes.graphical
Subinterfaces of GridOffset in org.refcodes.graphicalModifier and TypeInterfaceDescriptionstatic interfaceProvides an accessor for a Y offset property.static interfaceThe Interface GridOffsetProperty.Methods in org.refcodes.graphical that return GridOffsetModifier and TypeMethodDescriptiondefault GridOffsetGridOffset.GridOffsetProperty.letGridOffset(int aOffsetX, int aOffsetY) This method stores and passes through the given arguments, which is very useful for builder APIs: Sets the givenDimension(setter) as ofGridOffset.GridOffsetMutator.setGridOffset(int, int)and returns the very same values encapsulated asGridOffsetinstance.default GridOffsetGridOffset.GridOffsetProperty.letGridOffset(GridOffset aGridOffset) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenGridOffset(setter) as ofGridOffset.GridOffsetMutator.setGridOffset(GridOffset)and returns the very same value (getter).Methods in org.refcodes.graphical with parameters of type GridOffsetModifier and TypeMethodDescriptionstatic booleanGridOffset.equals(GridOffset aOffsetA, GridOffset aOffsetB) Equals.default GridOffsetGridOffset.GridOffsetProperty.letGridOffset(GridOffset aGridOffset) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenGridOffset(setter) as ofGridOffset.GridOffsetMutator.setGridOffset(GridOffset)and returns the very same value (getter).voidGridOffset.GridOffsetMutator.setGridOffset(GridOffset aOffset) Sets the grid offset.GridOffset.GridOffsetBuilder.withGridOffset(GridOffset aOffset) With grid offset.