Uses of Enum Class
org.refcodes.graphical.LayoutMode
-
Uses of LayoutMode in org.refcodes.graphical
Subclasses with type arguments of type LayoutMode in org.refcodes.graphicalModifier and TypeClassDescriptionenumSpecifies a layout mode in terms of "horizontal" and "vertical".Methods in org.refcodes.graphical that return LayoutModeModifier and TypeMethodDescriptionLayoutModeAccessor.getLayoutMode()Retrieves the layout mode from the layout mode property.default LayoutModeLayoutModeAccessor.LayoutModeProperty.letLayoutMode(LayoutMode aLayoutMode) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenLayoutMode(setter) as ofLayoutModeAccessor.LayoutModeMutator.setLayoutMode(LayoutMode)and returns the very same value (getter).static LayoutModeReturns the enum constant of this class with the specified name.static LayoutMode[]LayoutMode.values()Returns an array containing the constants of this enum class, in the order they are declared.Methods in org.refcodes.graphical with parameters of type LayoutModeModifier and TypeMethodDescriptiondefault LayoutModeLayoutModeAccessor.LayoutModeProperty.letLayoutMode(LayoutMode aLayoutMode) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenLayoutMode(setter) as ofLayoutModeAccessor.LayoutModeMutator.setLayoutMode(LayoutMode)and returns the very same value (getter).voidLayoutModeAccessor.LayoutModeMutator.setLayoutMode(LayoutMode aLayoutMode) Sets the layout mode for the layout mode property.LayoutModeAccessor.LayoutModeBuilder.withLayoutMode(LayoutMode aLayoutMode) Sets the layout mode for the layout mode property.