Uses of Interface
org.refcodes.graphical.LeftPaddingAccessor.LeftPaddingBuilder
-
Uses of LeftPaddingAccessor.LeftPaddingBuilder in org.refcodes.graphical
Classes in org.refcodes.graphical with type parameters of type LeftPaddingAccessor.LeftPaddingBuilderModifier and TypeInterfaceDescriptionstatic interfaceProvides a builder method for a left padding property returning the builder for applying multiple build operations.Subinterfaces of LeftPaddingAccessor.LeftPaddingBuilder in org.refcodes.graphicalModifier and TypeInterfaceDescriptionstatic interfacePadding.PaddingBuilder<B extends Padding.PaddingBuilder<B>>The Interface PaddingBuilder.