Uses of Enum Class
org.refcodes.graphical.MoveMode
-
Uses of MoveMode in org.refcodes.graphical
Subclasses with type arguments of type MoveMode in org.refcodes.graphicalMethods in org.refcodes.graphical that return MoveModeModifier and TypeMethodDescriptionMoveModeAccessor.getMoveMode()Retrieves the move mode from the move mode property.default MoveModeMoveModeAccessor.MoveModeProperty.letMoveMode(MoveMode aMoveMode) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenMoveMode(setter) as ofMoveModeAccessor.MoveModeMutator.setMoveMode(MoveMode)and returns the very same value (getter).static MoveModeReturns the enum constant of this class with the specified name.static MoveMode[]MoveMode.values()Returns an array containing the constants of this enum class, in the order they are declared.Methods in org.refcodes.graphical with parameters of type MoveModeModifier and TypeMethodDescriptiondefault MoveModeMoveModeAccessor.MoveModeProperty.letMoveMode(MoveMode aMoveMode) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenMoveMode(setter) as ofMoveModeAccessor.MoveModeMutator.setMoveMode(MoveMode)and returns the very same value (getter).voidMoveModeAccessor.MoveModeMutator.setMoveMode(MoveMode aMoveMode) Sets the move mode for the move mode property.MoveModeAccessor.MoveModeBuilder.withMoveMode(MoveMode aMoveMode) Sets the move mode for the move mode property.