Uses of Interface
org.refcodes.graphical.MoveModeAccessor.MoveModeBuilder
-
Uses of MoveModeAccessor.MoveModeBuilder in org.refcodes.graphical
Classes in org.refcodes.graphical with type parameters of type MoveModeAccessor.MoveModeBuilderModifier and TypeInterfaceDescriptionstatic interfaceProvides a builder method for a move mode property returning the builder for applying multiple build operations.Subinterfaces of MoveModeAccessor.MoveModeBuilder in org.refcodes.graphicalModifier and TypeInterfaceDescriptioninterfaceGridViewportPane<C, B extends GridViewportPane<C,B>> The interfaceGridViewportPanedescribes the functionality of a graphical viewport onto a grid (such as a checkerboard): Just the viewport portion of a (larger) grid is displayed according to the settings of thisGridViewportPane.