Uses of Interface
org.refcodes.graphical.Offset
-
Uses of Offset in org.refcodes.graphical
Subinterfaces of Offset in org.refcodes.graphicalModifier and TypeInterfaceDescriptionstatic interfaceProvides an accessor for a Y offset property.static interfaceThe Interface OffsetProperty.Methods in org.refcodes.graphical that return OffsetModifier and TypeMethodDescriptiondefault OffsetOffset.OffsetProperty.letOffset(int aOffsetX, int aOffsetY) This method stores and passes through the given arguments, which is very useful for builder APIs: Sets the givenDimension(setter) as ofOffset.OffsetMutator.setOffset(int, int)and returns the very same values encapsulated asOffsetinstance.default OffsetThis method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenOffset(setter) as ofOffset.OffsetMutator.setOffset(Offset)and returns the very same value (getter).Methods in org.refcodes.graphical with parameters of type OffsetModifier and TypeMethodDescriptionstatic booleanEquals.default OffsetThis method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenOffset(setter) as ofOffset.OffsetMutator.setOffset(Offset)and returns the very same value (getter).voidGridOffset.GridOffsetMutator.setGridOffset(Offset aOffset) Sets the grid offset.voidSets the offset.voidViewportOffset.ViewportOffsetMutator.setViewportOffset(Offset aOffset) Sets the viewport offset.GridOffset.GridOffsetBuilder.withGridOffset(Offset aOffset) With grid offset.Offset.OffsetBuilder.withOffset(Offset aOffset) With offset.ViewportOffset.ViewportOffsetBuilder.withViewportOffset(Offset aOffset) With viewport offset.