JavaScript is disabled on your browser.
Skip navigation links
Module
Package
Class
Use
Tree
Index
Help
SEARCH:
Uses of Enum Class
org.refcodes.graphical.Opacity
Uses of
Opacity
in
org.refcodes.graphical
Methods in
org.refcodes.graphical
that return
Opacity
Modifier and Type
Method
Description
static
Opacity
Opacity.
valueOf
(
String
name)
Returns the enum constant of this class with the specified name.
static
Opacity
[]
Opacity.
values
()
Returns an array containing the constants of this enum class, in the order they are declared.