Uses of Interface
org.refcodes.graphical.Padding
-
Uses of Padding in org.refcodes.graphical
Subinterfaces of Padding in org.refcodes.graphicalModifier and TypeInterfaceDescriptionstatic interfaceProvides an accessor for a padding property.static interfaceThe Interface PaddingProperty.Methods in org.refcodes.graphical that return PaddingModifier and TypeMethodDescriptiondefault PaddingPadding.PaddingProperty.letPadding(int aTopPadding, int aRightPadding, int aBottomPadding, int aLeftPadding) This method stores and passes through the given arguments, which is very useful for builder APIs.default PaddingPadding.PaddingProperty.letPadding(Padding aPadding) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenPadding(setter) as ofPadding.PaddingMutator.setPadding(Padding)and returns the very same value (getter).Methods in org.refcodes.graphical with parameters of type PaddingModifier and TypeMethodDescriptionstatic booleanEquals.default PaddingPadding.PaddingProperty.letPadding(Padding aPadding) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenPadding(setter) as ofPadding.PaddingMutator.setPadding(Padding)and returns the very same value (getter).voidPadding.PaddingMutator.setPadding(Padding aPadding) Sets the padding.Padding.PaddingBuilder.withPadding(Padding aPadding) With padding.