Uses of Interface
org.refcodes.graphical.Pixmap
-
-
Uses of Pixmap in org.refcodes.graphical
Subinterfaces of Pixmap in org.refcodes.graphical Modifier and Type Interface Description static interfacePixmap.PixmapBuilder<PX,B extends Pixmap.PixmapBuilder<PX,B>>Provides a builder method for a pixmap property returning the builder for applying multiple build operations.static interfacePixmap.PixmapProperty<PX>Provides a pixmap property.interfaceRgbPixmapThe Interface RgbPixmap.static interfaceRgbPixmap.RgbPixmapBuilderThe Interface RgbPixmapBuilder.static interfaceRgbPixmap.RgbPixmapPropertyThe Interface RgbPixmapProperty.Classes in org.refcodes.graphical that implement Pixmap Modifier and Type Class Description classRgbPixmapBuilderImplThe Class RgbPixmapBuilderImpl.classRgbPixmapImplThe Class RgbPixmapImpl.Methods in org.refcodes.graphical that return Pixmap Modifier and Type Method Description Pixmap<PX>PixmapImageBuilder. toPixmap()To pixmap.Methods in org.refcodes.graphical with parameters of type Pixmap Modifier and Type Method Description default voidPixmap.PixmapBuilder. mergeColorArrays(Pixmap<PX> aSourceColorArray)Merge color arrays.
-