Uses of Interface
org.refcodes.graphical.Position
-
Uses of Position in org.refcodes.graphical
Subinterfaces of Position in org.refcodes.graphicalModifier and TypeInterfaceDescriptionstatic interfaceThe Interface PositionProperty.interfaceProvides an accessor for a rectangle property (dimension and height).static interfaceProvides a property (getter / setter) for a rectangle property (dimension and height).Classes in org.refcodes.graphical that implement PositionModifier and TypeClassDescriptionclassThe classPositionImplclass implements thePositioninterface.classThe Class PositionPropertyBuilder.classThe classRectangleImplimplements theRectangleinterface.Methods in org.refcodes.graphical that return PositionModifier and TypeMethodDescriptiondefault PositionGridOffset.GridOffsetProperty.letGridOffset(Position aPosition) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenPosition(setter) as ofGridOffset.GridOffsetMutator.setGridOffset(Position)and returns the very same value (getter).default PositionThis method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenPosition(setter) as ofOffset.OffsetMutator.setOffset(Position)and returns the very same value (getter).default PositionPosition.PositionProperty.letPosition(int aPosX, int aPosY) This method stores and passes through the given arguments, which is very useful for builder APIs: Sets the givenDimension(setter) as ofPosition.PositionMutator.setPosition(int, int)and returns the very same values encapsulated asPositioninstance.default PositionPosition.PositionProperty.letPosition(Position aPosition) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenPosition(setter) as ofPosition.PositionMutator.setPosition(Position)and returns the very same value (getter).default Positiondefault PositionMethods in org.refcodes.graphical with parameters of type PositionModifier and TypeMethodDescriptiondefault voidstatic booleanEquals.default booleanGridDimension.isInBounds(Position aPosition) Tests whether the given position is inside of the bounds of the grid.default PositionGridOffset.GridOffsetProperty.letGridOffset(Position aPosition) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenPosition(setter) as ofGridOffset.GridOffsetMutator.setGridOffset(Position)and returns the very same value (getter).default PositionThis method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenPosition(setter) as ofOffset.OffsetMutator.setOffset(Position)and returns the very same value (getter).default PositionPosition.PositionProperty.letPosition(Position aPosition) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenPosition(setter) as ofPosition.PositionMutator.setPosition(Position)and returns the very same value (getter).voidGridOffset.GridOffsetMutator.setGridOffset(Position aOffset) Sets the grid offset.voidSets the offset.voidPosition.PositionMutator.setPosition(Position aPosition) Sets the position.voidPositionPropertyBuilder.setPosition(Position aPosition) Sets the position.voidViewportOffset.ViewportOffsetMutator.setViewportOffset(Position aOffset) Sets the viewport offset.default voiddefault Positiondefault PositionGridOffset.GridOffsetBuilder.withGridOffset(Position aOffset) With grid offset.Offset.OffsetBuilder.withOffset(Position aOffset) With offset.Position.PositionBuilder.withPosition(Position aPosition) With position.PositionPropertyBuilder.withPosition(Position aPosition) With position.ViewportOffset.ViewportOffsetBuilder.withViewportOffset(Position aOffset) With viewport offset.Constructors in org.refcodes.graphical with parameters of type PositionModifierConstructorDescriptionRectangleImpl(Position aPosition, Dimension aDimension) Constructs aRectanglewith the given metrics.