Uses of Interface
org.refcodes.graphical.RightPaddingAccessor.RightPaddingBuilder
-
Uses of RightPaddingAccessor.RightPaddingBuilder in org.refcodes.graphical
Classes in org.refcodes.graphical with type parameters of type RightPaddingAccessor.RightPaddingBuilderModifier and TypeInterfaceDescriptionstatic interfaceProvides a builder method for a right padding property returning the builder for applying multiple build operations.Subinterfaces of RightPaddingAccessor.RightPaddingBuilder in org.refcodes.graphicalModifier and TypeInterfaceDescriptionstatic interfacePadding.PaddingBuilder<B extends Padding.PaddingBuilder<B>>The Interface PaddingBuilder.