Uses of Enum Class
org.refcodes.graphical.ScaleMode
-
Uses of ScaleMode in org.refcodes.graphical
Subclasses with type arguments of type ScaleMode in org.refcodes.graphicalMethods in org.refcodes.graphical that return ScaleModeModifier and TypeMethodDescriptionScaleModeAccessor.getScaleMode()Retrieves the scale mode from the scale mode property.default ScaleModeScaleModeAccessor.ScaleModeProperty.letScaleMode(ScaleMode aScaleMode) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenScaleMode(setter) as ofScaleModeAccessor.ScaleModeMutator.setScaleMode(ScaleMode)and returns the very same value (getter).static ScaleModeReturns the enum constant of this class with the specified name.static ScaleMode[]ScaleMode.values()Returns an array containing the constants of this enum class, in the order they are declared.Methods in org.refcodes.graphical with parameters of type ScaleModeModifier and TypeMethodDescriptiondefault ScaleModeScaleModeAccessor.ScaleModeProperty.letScaleMode(ScaleMode aScaleMode) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenScaleMode(setter) as ofScaleModeAccessor.ScaleModeMutator.setScaleMode(ScaleMode)and returns the very same value (getter).voidScaleModeAccessor.ScaleModeMutator.setScaleMode(ScaleMode aScaleMode) Sets the scale mode for the scale mode property.ScaleModeAccessor.ScaleModeBuilder.withScaleMode(ScaleMode aScaleMode) Sets the scale mode for the scale mode property.