Uses of Interface
org.refcodes.graphical.ScaleModeAccessor.ScaleModeBuilder
-
Uses of ScaleModeAccessor.ScaleModeBuilder in org.refcodes.graphical
Classes in org.refcodes.graphical with type parameters of type ScaleModeAccessor.ScaleModeBuilderModifier and TypeInterfaceDescriptionstatic interfaceProvides a builder method for a scale mode property returning the builder for applying multiple build operations.