Package org.refcodes.graphical
Interface BackgroundAccessor<T>
-
- Type Parameters:
T- The background's type to be accessed.
- All Known Subinterfaces:
BackgroundAccessor.BackgroundProperty<T>
public interface BackgroundAccessor<T>Provides an accessor for a background property.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceBackgroundAccessor.BackgroundBuilder<T,B extends BackgroundAccessor.BackgroundBuilder<T,B>>Provides a builder method for a background property returning the builder for applying multiple build operations.static interfaceBackgroundAccessor.BackgroundMutator<T>Provides a mutator for a background property.static interfaceBackgroundAccessor.BackgroundProperty<T>Provides a background property.
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description TgetBackground()Retrieves the background from the background property.
-
-
-
Method Detail
-
getBackground
T getBackground()
Retrieves the background from the background property.- Returns:
- The background stored by the background property.
-
-