Package org.refcodes.graphical
Interface ContainerHeightAccessor
-
- All Known Subinterfaces:
ContainerDimension,ContainerDimension.ContainerDimensionProperty,ContainerDimension.ContainerDimensionPropertyBuilder,ContainerHeightAccessor.ContainerHeightProperty
public interface ContainerHeightAccessorProvides an accessor for a container height property.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceContainerHeightAccessor.ContainerHeightBuilder<B extends ContainerHeightAccessor.ContainerHeightBuilder<B>>Provides a builder method for a container height property returning the builder for applying multiple build operations.static interfaceContainerHeightAccessor.ContainerHeightMutatorProvides a mutator for a container height property.static interfaceContainerHeightAccessor.ContainerHeightPropertyProvides a container height property.
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description intgetContainerHeight()Retrieves the container height from the container height property.
-