Package org.refcodes.graphical
Interface ContainerHeightAccessor.ContainerHeightBuilder<B extends ContainerHeightAccessor.ContainerHeightBuilder<B>>
-
- Type Parameters:
B- The builder to return in order to be able to apply multiple build operations.
- All Known Subinterfaces:
ContainerDimension.ContainerDimensionBuilder<B>,ContainerDimension.ContainerDimensionPropertyBuilder
- Enclosing interface:
- ContainerHeightAccessor
public static interface ContainerHeightAccessor.ContainerHeightBuilder<B extends ContainerHeightAccessor.ContainerHeightBuilder<B>>Provides a builder method for a container height property returning the builder for applying multiple build operations.
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description BwithContainerHeight(int aHeight)Sets the container height for the container height property.
-
-
-
Method Detail
-
withContainerHeight
B withContainerHeight(int aHeight)
Sets the container height for the container height property.- Parameters:
aHeight- The container height to be stored by the container height property.- Returns:
- The builder for applying multiple build operations.
-
-