Package org.refcodes.graphical
Interface ContainerHeightAccessor.ContainerHeightMutator
-
- All Known Subinterfaces:
ContainerDimension.ContainerDimensionMutator,ContainerDimension.ContainerDimensionProperty,ContainerDimension.ContainerDimensionPropertyBuilder,ContainerHeightAccessor.ContainerHeightProperty
- Enclosing interface:
- ContainerHeightAccessor
public static interface ContainerHeightAccessor.ContainerHeightMutatorProvides a mutator for a container height property.
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description voidsetContainerHeight(int aHeight)Sets the container height for the container height property.
-