Package org.refcodes.graphical
Interface ContentAccessor<T>
-
- Type Parameters:
T- The content's type to be accessed.
- All Known Subinterfaces:
ContentAccessor.ContentProperty<T>,ViewportPane<B>
public interface ContentAccessor<T>Provides an accessor for a content property.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceContentAccessor.ContentBuilder<T,B extends ContentAccessor.ContentBuilder<T,B>>Provides a builder method for a content property returning the builder for applying multiple build operations.static interfaceContentAccessor.ContentMutator<T>Provides a mutator for a content property.static interfaceContentAccessor.ContentProperty<T>Provides a content property.
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description TgetContent()Retrieves the content from the content property.
-
-
-
Method Detail
-
getContent
T getContent()
Retrieves the content from the content property.- Returns:
- The content stored by the content property.
-
-