Package org.refcodes.graphical
Interface ContentAccessor.ContentMutator<T>
-
- Type Parameters:
T- The content's type to be accessed.
- All Known Subinterfaces:
ContentAccessor.ContentProperty<T>,ViewportPane<B>
- Enclosing interface:
- ContentAccessor<T>
public static interface ContentAccessor.ContentMutator<T>Provides a mutator for a content property.
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description voidsetContent(T aContent)Sets the content for the content property.
-
-
-
Method Detail
-
setContent
void setContent(T aContent)
Sets the content for the content property.- Parameters:
aContent- The content to be stored by the content property.
-
-