Package org.refcodes.graphical
Class DimensionImpl
- java.lang.Object
-
- org.refcodes.graphical.DimensionImpl
-
- All Implemented Interfaces:
Dimension,HeightAccessor,WidthAccessor
- Direct Known Subclasses:
DimensionImpl.DimensionPropertyBuilderImpl
public class DimensionImpl extends java.lang.Object implements Dimension
The Class DimensionImpl.- Author:
- steiner
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classDimensionImpl.DimensionPropertyBuilderImplThe Class DimensionPropertyBuilderImpl.-
Nested classes/interfaces inherited from interface org.refcodes.graphical.Dimension
Dimension.DimensionBuilder<B extends Dimension.DimensionBuilder<B>>, Dimension.DimensionMutator, Dimension.DimensionProperty, Dimension.DimensionPropertyBuilder
-
Nested classes/interfaces inherited from interface org.refcodes.graphical.HeightAccessor
HeightAccessor.HeightBuilder<B extends HeightAccessor.HeightBuilder<B>>, HeightAccessor.HeightMutator, HeightAccessor.HeightProperty
-
Nested classes/interfaces inherited from interface org.refcodes.graphical.WidthAccessor
WidthAccessor.WidthBuilder<B extends WidthAccessor.WidthBuilder<B>>, WidthAccessor.WidthMutator, WidthAccessor.WidthProperty
-
-
Constructor Summary
Constructors Modifier Constructor Description protectedDimensionImpl()Instantiates a new dimension impl.DimensionImpl(int aWidth, int aHeight)Instantiates a new dimension impl.
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description intgetHeight()Retrieves the height from the height property.intgetWidth()Retrieves the width from the width property.java.lang.StringtoString()
-
-
-
Method Detail
-
getWidth
public int getWidth()
Retrieves the width from the width property.- Specified by:
getWidthin interfaceWidthAccessor- Returns:
- The width stored by the width property.
-
getHeight
public int getHeight()
Retrieves the height from the height property.- Specified by:
getHeightin interfaceHeightAccessor- Returns:
- The height stored by the height property.
-
toString
public java.lang.String toString()
- Overrides:
toStringin classjava.lang.Object
-
-