Package org.refcodes.graphical
Class DimensionImpl.DimensionPropertyBuilderImpl
- java.lang.Object
-
- org.refcodes.graphical.DimensionImpl
-
- org.refcodes.graphical.DimensionImpl.DimensionPropertyBuilderImpl
-
- All Implemented Interfaces:
Dimension,Dimension.DimensionBuilder<Dimension.DimensionPropertyBuilder>,Dimension.DimensionMutator,Dimension.DimensionProperty,Dimension.DimensionPropertyBuilder,HeightAccessor,HeightAccessor.HeightBuilder<Dimension.DimensionPropertyBuilder>,HeightAccessor.HeightMutator,HeightAccessor.HeightProperty,WidthAccessor,WidthAccessor.WidthBuilder<Dimension.DimensionPropertyBuilder>,WidthAccessor.WidthMutator,WidthAccessor.WidthProperty
- Enclosing class:
- DimensionImpl
public static class DimensionImpl.DimensionPropertyBuilderImpl extends DimensionImpl implements Dimension.DimensionPropertyBuilder
The Class DimensionPropertyBuilderImpl.
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.graphical.Dimension
Dimension.DimensionBuilder<B extends Dimension.DimensionBuilder<B>>, Dimension.DimensionMutator, Dimension.DimensionProperty, Dimension.DimensionPropertyBuilder
-
Nested classes/interfaces inherited from class org.refcodes.graphical.DimensionImpl
DimensionImpl.DimensionPropertyBuilderImpl
-
Nested classes/interfaces inherited from interface org.refcodes.graphical.HeightAccessor
HeightAccessor.HeightBuilder<B extends HeightAccessor.HeightBuilder<B>>, HeightAccessor.HeightMutator, HeightAccessor.HeightProperty
-
Nested classes/interfaces inherited from interface org.refcodes.graphical.WidthAccessor
WidthAccessor.WidthBuilder<B extends WidthAccessor.WidthBuilder<B>>, WidthAccessor.WidthMutator, WidthAccessor.WidthProperty
-
-
Field Summary
-
Fields inherited from class org.refcodes.graphical.DimensionImpl
_height, _width
-
-
Constructor Summary
Constructors Constructor Description DimensionPropertyBuilderImpl()Instantiates a new dimension property builder impl.DimensionPropertyBuilderImpl(int aWidth, int aHeight)Instantiates a new dimension property builder impl.
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description voidsetDimension(int aWidth, int aHeight)Sets the dimension.voidsetDimension(Dimension aDimension)Sets the dimension.voidsetHeight(int aHeight)Sets the height for the height property.voidsetWidth(int aWidth)Sets the width for the width property.DimensionImpl.DimensionPropertyBuilderImplwithDimension(int aWidth, int aHeight)With dimension.DimensionImpl.DimensionPropertyBuilderImplwithDimension(Dimension aDimension)With dimension.DimensionImpl.DimensionPropertyBuilderImplwithHeight(int aHeight)Sets the height for the height property.DimensionImpl.DimensionPropertyBuilderImplwithWidth(int aWidth)Sets the width for the width property.-
Methods inherited from class org.refcodes.graphical.DimensionImpl
getHeight, getWidth, toString
-
Methods inherited from interface org.refcodes.graphical.HeightAccessor
getHeight
-
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface org.refcodes.graphical.WidthAccessor
getWidth
-
-
-
-
Constructor Detail
-
DimensionPropertyBuilderImpl
public DimensionPropertyBuilderImpl()
Instantiates a new dimension property builder impl.
-
DimensionPropertyBuilderImpl
public DimensionPropertyBuilderImpl(int aWidth, int aHeight)Instantiates a new dimension property builder impl.- Parameters:
aWidth- the widthaHeight- the height
-
-
Method Detail
-
setWidth
public void setWidth(int aWidth)
Sets the width for the width property.- Specified by:
setWidthin interfaceWidthAccessor.WidthMutator- Parameters:
aWidth- The width to be stored by the width property.
-
withWidth
public DimensionImpl.DimensionPropertyBuilderImpl withWidth(int aWidth)
Sets the width for the width property.- Specified by:
withWidthin interfaceWidthAccessor.WidthBuilder<Dimension.DimensionPropertyBuilder>- Parameters:
aWidth- The width to be stored by the width property.- Returns:
- The builder for applying multiple build operations.
-
setHeight
public void setHeight(int aHeight)
Sets the height for the height property.- Specified by:
setHeightin interfaceHeightAccessor.HeightMutator- Parameters:
aHeight- The height to be stored by the height property.
-
withHeight
public DimensionImpl.DimensionPropertyBuilderImpl withHeight(int aHeight)
Sets the height for the height property.- Specified by:
withHeightin interfaceHeightAccessor.HeightBuilder<Dimension.DimensionPropertyBuilder>- Parameters:
aHeight- The height to be stored by the height property.- Returns:
- The builder for applying multiple build operations.
-
withDimension
public DimensionImpl.DimensionPropertyBuilderImpl withDimension(int aWidth, int aHeight)
With dimension.- Specified by:
withDimensionin interfaceDimension.DimensionBuilder<Dimension.DimensionPropertyBuilder>- Parameters:
aWidth- the widthaHeight- the height- Returns:
- the b
-
withDimension
public DimensionImpl.DimensionPropertyBuilderImpl withDimension(Dimension aDimension)
With dimension.- Specified by:
withDimensionin interfaceDimension.DimensionBuilder<Dimension.DimensionPropertyBuilder>- Parameters:
aDimension- the dimension- Returns:
- the b
-
setDimension
public void setDimension(int aWidth, int aHeight)Sets the dimension.- Specified by:
setDimensionin interfaceDimension.DimensionMutator- Parameters:
aWidth- the widthaHeight- the height
-
setDimension
public void setDimension(Dimension aDimension)
Sets the dimension.- Specified by:
setDimensionin interfaceDimension.DimensionMutator- Parameters:
aDimension- the new dimension
-
-