Package org.refcodes.graphical
Interface FieldDimension
-
- All Superinterfaces:
FieldGapAccessor,FieldHeightAccessor,FieldWidthAccessor
- All Known Subinterfaces:
FieldDimension.FieldDimensionProperty,FieldDimension.FieldDimensionPropertyBuilder,Raster,Raster.RasterProperty,Raster.RasterPropertyBuilder,ViewportPane<B>
- All Known Implementing Classes:
FieldDimensionImpl,FieldDimensionImpl.FieldDimensionPropertyBuilderImpl,RasterImpl,RasterImpl.RasterPropertyBuilderImpl
public interface FieldDimension extends FieldHeightAccessor, FieldWidthAccessor, FieldGapAccessor
Provides an accessor for aFieldDimensionproperty.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceFieldDimension.FieldDimensionBuilder<B extends FieldDimension.FieldDimensionBuilder<B>>The Interface FieldDimensionBuilder.static interfaceFieldDimension.FieldDimensionMutatorThe Interface FieldDimensionMutator.static interfaceFieldDimension.FieldDimensionPropertyThe Interface FieldDimensionProperty.static interfaceFieldDimension.FieldDimensionPropertyBuilderThe Interface FieldDimensionPropertyBuilder.-
Nested classes/interfaces inherited from interface org.refcodes.graphical.FieldGapAccessor
FieldGapAccessor.FieldGapBuilder<B extends FieldGapAccessor.FieldGapBuilder<B>>, FieldGapAccessor.FieldGapMutator, FieldGapAccessor.FieldGapProperty
-
Nested classes/interfaces inherited from interface org.refcodes.graphical.FieldHeightAccessor
FieldHeightAccessor.FieldHeightBuilder<B extends FieldHeightAccessor.FieldHeightBuilder<B>>, FieldHeightAccessor.FieldHeightMutator, FieldHeightAccessor.FieldHeightProperty
-
Nested classes/interfaces inherited from interface org.refcodes.graphical.FieldWidthAccessor
FieldWidthAccessor.FieldWidthBuilder<B extends FieldWidthAccessor.FieldWidthBuilder<B>>, FieldWidthAccessor.FieldWidthMutator, FieldWidthAccessor.FieldWidthProperty
-
-
Method Summary
All Methods Static Methods Default Methods Modifier and Type Method Description static booleanequals(FieldDimension aFieldDimensionA, FieldDimension aFieldDimensionB)Equals.-
Methods inherited from interface org.refcodes.graphical.FieldGapAccessor
getFieldGap
-
Methods inherited from interface org.refcodes.graphical.FieldHeightAccessor
getFieldHeight
-
Methods inherited from interface org.refcodes.graphical.FieldWidthAccessor
getFieldWidth
-
-
-
-
Method Detail
-
equals
static boolean equals(FieldDimension aFieldDimensionA, FieldDimension aFieldDimensionB)
Equals.- Parameters:
aFieldDimensionA- the field dimension AaFieldDimensionB- the field dimension B- Returns:
- true, if successful
-
-