Package org.refcodes.graphical
Class FieldDimensionImpl
- java.lang.Object
-
- org.refcodes.graphical.FieldDimensionImpl
-
- All Implemented Interfaces:
FieldDimension,FieldGapAccessor,FieldHeightAccessor,FieldWidthAccessor
- Direct Known Subclasses:
FieldDimensionImpl.FieldDimensionPropertyBuilderImpl
public class FieldDimensionImpl extends java.lang.Object implements FieldDimension
The Class FieldDimensionImpl.- Author:
- steiner
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classFieldDimensionImpl.FieldDimensionPropertyBuilderImplThe Class FieldDimensionPropertyBuilderImpl.-
Nested classes/interfaces inherited from interface org.refcodes.graphical.FieldDimension
FieldDimension.FieldDimensionBuilder<B extends FieldDimension.FieldDimensionBuilder<B>>, FieldDimension.FieldDimensionMutator, FieldDimension.FieldDimensionProperty, FieldDimension.FieldDimensionPropertyBuilder
-
Nested classes/interfaces inherited from interface org.refcodes.graphical.FieldGapAccessor
FieldGapAccessor.FieldGapBuilder<B extends FieldGapAccessor.FieldGapBuilder<B>>, FieldGapAccessor.FieldGapMutator, FieldGapAccessor.FieldGapProperty
-
Nested classes/interfaces inherited from interface org.refcodes.graphical.FieldHeightAccessor
FieldHeightAccessor.FieldHeightBuilder<B extends FieldHeightAccessor.FieldHeightBuilder<B>>, FieldHeightAccessor.FieldHeightMutator, FieldHeightAccessor.FieldHeightProperty
-
Nested classes/interfaces inherited from interface org.refcodes.graphical.FieldWidthAccessor
FieldWidthAccessor.FieldWidthBuilder<B extends FieldWidthAccessor.FieldWidthBuilder<B>>, FieldWidthAccessor.FieldWidthMutator, FieldWidthAccessor.FieldWidthProperty
-
-
Field Summary
Fields Modifier and Type Field Description protected int_fieldGapprotected int_fieldHeightprotected int_fieldWidth
-
Constructor Summary
Constructors Modifier Constructor Description protectedFieldDimensionImpl()Instantiates a new field dimension impl.FieldDimensionImpl(int aWidth, int aHeight, int aFieldGap)Instantiates a new field dimension impl.
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description intgetFieldGap()Retrieves the field gap from the field gap property.intgetFieldHeight()Retrieves the field height from the field height property.intgetFieldWidth()Retrieves the field width from the field width property.java.lang.StringtoString()-
Methods inherited from interface org.refcodes.graphical.FieldDimension
equals
-
-
-
-
Constructor Detail
-
FieldDimensionImpl
protected FieldDimensionImpl()
Instantiates a new field dimension impl.
-
FieldDimensionImpl
public FieldDimensionImpl(int aWidth, int aHeight, int aFieldGap)Instantiates a new field dimension impl.- Parameters:
aWidth- the widthaHeight- the heightaFieldGap- the field gap
-
-
Method Detail
-
getFieldWidth
public int getFieldWidth()
Retrieves the field width from the field width property.- Specified by:
getFieldWidthin interfaceFieldWidthAccessor- Returns:
- The field width stored by the field width property.
-
getFieldHeight
public int getFieldHeight()
Retrieves the field height from the field height property.- Specified by:
getFieldHeightin interfaceFieldHeightAccessor- Returns:
- The field height stored by the field height property.
-
getFieldGap
public int getFieldGap()
Retrieves the field gap from the field gap property.- Specified by:
getFieldGapin interfaceFieldGapAccessor- Returns:
- The field gap stored by the field gap property.
-
toString
public java.lang.String toString()
- Overrides:
toStringin classjava.lang.Object
-
-