Package org.refcodes.graphical
Class FieldDimensionImpl.FieldDimensionPropertyBuilderImpl
- java.lang.Object
-
- org.refcodes.graphical.FieldDimensionImpl
-
- org.refcodes.graphical.FieldDimensionImpl.FieldDimensionPropertyBuilderImpl
-
- All Implemented Interfaces:
FieldDimension,FieldDimension.FieldDimensionBuilder<FieldDimension.FieldDimensionPropertyBuilder>,FieldDimension.FieldDimensionMutator,FieldDimension.FieldDimensionProperty,FieldDimension.FieldDimensionPropertyBuilder,FieldGapAccessor,FieldGapAccessor.FieldGapBuilder<FieldDimension.FieldDimensionPropertyBuilder>,FieldGapAccessor.FieldGapMutator,FieldGapAccessor.FieldGapProperty,FieldHeightAccessor,FieldHeightAccessor.FieldHeightBuilder<FieldDimension.FieldDimensionPropertyBuilder>,FieldHeightAccessor.FieldHeightMutator,FieldHeightAccessor.FieldHeightProperty,FieldWidthAccessor,FieldWidthAccessor.FieldWidthBuilder<FieldDimension.FieldDimensionPropertyBuilder>,FieldWidthAccessor.FieldWidthMutator,FieldWidthAccessor.FieldWidthProperty
- Enclosing class:
- FieldDimensionImpl
public static class FieldDimensionImpl.FieldDimensionPropertyBuilderImpl extends FieldDimensionImpl implements FieldDimension.FieldDimensionPropertyBuilder
The Class FieldDimensionPropertyBuilderImpl.
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.graphical.FieldDimension
FieldDimension.FieldDimensionBuilder<B extends FieldDimension.FieldDimensionBuilder<B>>, FieldDimension.FieldDimensionMutator, FieldDimension.FieldDimensionProperty, FieldDimension.FieldDimensionPropertyBuilder
-
Nested classes/interfaces inherited from class org.refcodes.graphical.FieldDimensionImpl
FieldDimensionImpl.FieldDimensionPropertyBuilderImpl
-
Nested classes/interfaces inherited from interface org.refcodes.graphical.FieldGapAccessor
FieldGapAccessor.FieldGapBuilder<B extends FieldGapAccessor.FieldGapBuilder<B>>, FieldGapAccessor.FieldGapMutator, FieldGapAccessor.FieldGapProperty
-
Nested classes/interfaces inherited from interface org.refcodes.graphical.FieldHeightAccessor
FieldHeightAccessor.FieldHeightBuilder<B extends FieldHeightAccessor.FieldHeightBuilder<B>>, FieldHeightAccessor.FieldHeightMutator, FieldHeightAccessor.FieldHeightProperty
-
Nested classes/interfaces inherited from interface org.refcodes.graphical.FieldWidthAccessor
FieldWidthAccessor.FieldWidthBuilder<B extends FieldWidthAccessor.FieldWidthBuilder<B>>, FieldWidthAccessor.FieldWidthMutator, FieldWidthAccessor.FieldWidthProperty
-
-
Field Summary
-
Fields inherited from class org.refcodes.graphical.FieldDimensionImpl
_fieldGap, _fieldHeight, _fieldWidth
-
-
Constructor Summary
Constructors Constructor Description FieldDimensionPropertyBuilderImpl()Instantiates a new field dimension property builder impl.FieldDimensionPropertyBuilderImpl(int aWidth, int aHeight, int aGap)Instantiates a new field dimension property builder impl.
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description voidsetFieldDimension(int aWidth, int aHeight)Sets the field dimension.voidsetFieldDimension(int aWidth, int aHeight, int aGap)Sets the field dimension.voidsetFieldDimension(Dimension aDimension)Sets the field dimension.voidsetFieldDimension(FieldDimension aDimension)Sets the field dimension.voidsetFieldGap(int aFieldGap)Sets the field gap for the field gap property.voidsetFieldHeight(int aHeight)Sets the field height for the field height property.voidsetFieldWidth(int aWidth)Sets the field width for the field width property.FieldDimensionImpl.FieldDimensionPropertyBuilderImplwithFieldDimension(int aWidth, int aHeight)With field dimension.FieldDimensionImpl.FieldDimensionPropertyBuilderImplwithFieldDimension(int aWidth, int aHeight, int aGap)With field dimension.FieldDimensionImpl.FieldDimensionPropertyBuilderImplwithFieldDimension(Dimension aDimension)With field dimension.FieldDimensionImpl.FieldDimensionPropertyBuilderImplwithFieldDimension(FieldDimension aDimension)With field dimension.FieldDimensionImpl.FieldDimensionPropertyBuilderImplwithFieldGap(int aFieldGap)Sets the field gap for the field gap property.FieldDimensionImpl.FieldDimensionPropertyBuilderImplwithFieldHeight(int aHeight)Sets the field height for the field height property.FieldDimensionImpl.FieldDimensionPropertyBuilderImplwithFieldWidth(int aWidth)Sets the field width for the field width property.-
Methods inherited from interface org.refcodes.graphical.FieldDimension
equals
-
Methods inherited from class org.refcodes.graphical.FieldDimensionImpl
getFieldGap, getFieldHeight, getFieldWidth, toString
-
Methods inherited from interface org.refcodes.graphical.FieldGapAccessor
getFieldGap
-
Methods inherited from interface org.refcodes.graphical.FieldHeightAccessor
getFieldHeight
-
Methods inherited from interface org.refcodes.graphical.FieldWidthAccessor
getFieldWidth
-
-
-
-
Constructor Detail
-
FieldDimensionPropertyBuilderImpl
public FieldDimensionPropertyBuilderImpl()
Instantiates a new field dimension property builder impl.
-
FieldDimensionPropertyBuilderImpl
public FieldDimensionPropertyBuilderImpl(int aWidth, int aHeight, int aGap)Instantiates a new field dimension property builder impl.- Parameters:
aWidth- the widthaHeight- the heightaGap- the gap
-
-
Method Detail
-
setFieldWidth
public void setFieldWidth(int aWidth)
Sets the field width for the field width property.- Specified by:
setFieldWidthin interfaceFieldWidthAccessor.FieldWidthMutator- Parameters:
aWidth- The field width to be stored by the field width property.
-
withFieldWidth
public FieldDimensionImpl.FieldDimensionPropertyBuilderImpl withFieldWidth(int aWidth)
Sets the field width for the field width property.- Specified by:
withFieldWidthin interfaceFieldWidthAccessor.FieldWidthBuilder<FieldDimension.FieldDimensionPropertyBuilder>- Parameters:
aWidth- The field width to be stored by the field width property.- Returns:
- The builder for applying multiple build operations.
-
setFieldHeight
public void setFieldHeight(int aHeight)
Sets the field height for the field height property.- Specified by:
setFieldHeightin interfaceFieldHeightAccessor.FieldHeightMutator- Parameters:
aHeight- The field height to be stored by the field height property.
-
withFieldHeight
public FieldDimensionImpl.FieldDimensionPropertyBuilderImpl withFieldHeight(int aHeight)
Sets the field height for the field height property.- Specified by:
withFieldHeightin interfaceFieldHeightAccessor.FieldHeightBuilder<FieldDimension.FieldDimensionPropertyBuilder>- Parameters:
aHeight- The field height to be stored by the field height property.- Returns:
- The builder for applying multiple build operations.
-
withFieldDimension
public FieldDimensionImpl.FieldDimensionPropertyBuilderImpl withFieldDimension(int aWidth, int aHeight)
With field dimension.- Specified by:
withFieldDimensionin interfaceFieldDimension.FieldDimensionBuilder<FieldDimension.FieldDimensionPropertyBuilder>- Parameters:
aWidth- the field widthaHeight- the field height- Returns:
- the b
-
withFieldDimension
public FieldDimensionImpl.FieldDimensionPropertyBuilderImpl withFieldDimension(int aWidth, int aHeight, int aGap)
With field dimension.- Specified by:
withFieldDimensionin interfaceFieldDimension.FieldDimensionBuilder<FieldDimension.FieldDimensionPropertyBuilder>- Parameters:
aWidth- the field widthaHeight- the field heightaGap- the gap- Returns:
- the b
-
withFieldDimension
public FieldDimensionImpl.FieldDimensionPropertyBuilderImpl withFieldDimension(FieldDimension aDimension)
With field dimension.- Specified by:
withFieldDimensionin interfaceFieldDimension.FieldDimensionBuilder<FieldDimension.FieldDimensionPropertyBuilder>- Parameters:
aDimension- the field- Returns:
- the b
-
setFieldDimension
public void setFieldDimension(int aWidth, int aHeight)Sets the field dimension.- Specified by:
setFieldDimensionin interfaceFieldDimension.FieldDimensionMutator- Parameters:
aWidth- the field widthaHeight- the field height
-
setFieldDimension
public void setFieldDimension(int aWidth, int aHeight, int aGap)Sets the field dimension.- Specified by:
setFieldDimensionin interfaceFieldDimension.FieldDimensionMutator- Parameters:
aWidth- the field widthaHeight- the field heightaGap- the gap
-
setFieldDimension
public void setFieldDimension(FieldDimension aDimension)
Sets the field dimension.- Specified by:
setFieldDimensionin interfaceFieldDimension.FieldDimensionMutator- Parameters:
aDimension- the new field dimension
-
withFieldDimension
public FieldDimensionImpl.FieldDimensionPropertyBuilderImpl withFieldDimension(Dimension aDimension)
With field dimension.- Specified by:
withFieldDimensionin interfaceFieldDimension.FieldDimensionBuilder<FieldDimension.FieldDimensionPropertyBuilder>- Parameters:
aDimension- the dimension- Returns:
- the b
-
setFieldDimension
public void setFieldDimension(Dimension aDimension)
Sets the field dimension.- Specified by:
setFieldDimensionin interfaceFieldDimension.FieldDimensionMutator- Parameters:
aDimension- the new field dimension
-
setFieldGap
public void setFieldGap(int aFieldGap)
Sets the field gap for the field gap property.- Specified by:
setFieldGapin interfaceFieldGapAccessor.FieldGapMutator- Parameters:
aFieldGap- The field gap to be stored by the field gap property.
-
withFieldGap
public FieldDimensionImpl.FieldDimensionPropertyBuilderImpl withFieldGap(int aFieldGap)
Sets the field gap for the field gap property.- Specified by:
withFieldGapin interfaceFieldGapAccessor.FieldGapBuilder<FieldDimension.FieldDimensionPropertyBuilder>- Parameters:
aFieldGap- The field gap to be stored by the field gap property.- Returns:
- The builder for applying multiple build operations.
-
-