Package org.refcodes.graphical
Interface FieldWidthAccessor
-
- All Known Subinterfaces:
FieldDimension,FieldDimension.FieldDimensionProperty,FieldDimension.FieldDimensionPropertyBuilder,FieldWidthAccessor.FieldWidthProperty,Raster,Raster.RasterProperty,Raster.RasterPropertyBuilder,ViewportPane<B>
- All Known Implementing Classes:
FieldDimensionImpl,FieldDimensionImpl.FieldDimensionPropertyBuilderImpl,RasterImpl,RasterImpl.RasterPropertyBuilderImpl
public interface FieldWidthAccessorProvides an accessor for a field width property.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceFieldWidthAccessor.FieldWidthBuilder<B extends FieldWidthAccessor.FieldWidthBuilder<B>>Provides a builder method for a field width property returning the builder for applying multiple build operations.static interfaceFieldWidthAccessor.FieldWidthMutatorProvides a mutator for a field width property.static interfaceFieldWidthAccessor.FieldWidthPropertyProvides a field width property.
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description intgetFieldWidth()Retrieves the field width from the field width property.
-