Package org.refcodes.graphical
Interface GridHeightAccessor
-
- All Known Subinterfaces:
GridDimension,GridDimension.GridDimensionProperty,GridDimension.GridDimensionPropertyBuilder,GridHeightAccessor.GridHeightProperty,Raster,Raster.RasterProperty,Raster.RasterPropertyBuilder
- All Known Implementing Classes:
GridDimensionImpl,GridDimensionImpl.GridDimensionPropertyBuilderImpl,RasterImpl,RasterImpl.RasterPropertyBuilderImpl
public interface GridHeightAccessorProvides an accessor for a grid height property.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceGridHeightAccessor.GridHeightBuilder<B extends GridHeightAccessor.GridHeightBuilder<B>>Provides a builder method for a grid height property returning the builder for applying multiple build operations.static interfaceGridHeightAccessor.GridHeightMutatorProvides a mutator for a grid height property.static interfaceGridHeightAccessor.GridHeightPropertyProvides a grid height property.
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description intgetGridHeight()Retrieves the grid height from the grid height property.
-