Package org.refcodes.graphical
Interface GridModeAccessor
-
- All Known Subinterfaces:
GridModeAccessor.GridModeProperty,Raster,Raster.RasterProperty,Raster.RasterPropertyBuilder,ViewportPane<B>
- All Known Implementing Classes:
RasterImpl,RasterImpl.RasterPropertyBuilderImpl
public interface GridModeAccessorProvides an accessor for a grid mode property.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceGridModeAccessor.GridModeBuilder<B extends GridModeAccessor.GridModeBuilder<B>>Provides a builder method for a grid mode property returning the builder for applying multiple build operations.static interfaceGridModeAccessor.GridModeMutatorProvides a mutator for a grid mode property.static interfaceGridModeAccessor.GridModePropertyProvides a grid mode property.
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description GridModegetGridMode()Retrieves the grid mode from the grid mode property.
-
-
-
Method Detail
-
getGridMode
GridMode getGridMode()
Retrieves the grid mode from the grid mode property.- Returns:
- The grid mode stored by the grid mode property.
-
-