Package org.refcodes.graphical
Interface GridWidthAccessor
-
- All Known Subinterfaces:
GridDimension,GridDimension.GridDimensionProperty,GridDimension.GridDimensionPropertyBuilder,GridWidthAccessor.GridWidthProperty,Raster,Raster.RasterProperty,Raster.RasterPropertyBuilder
- All Known Implementing Classes:
GridDimensionImpl,GridDimensionImpl.GridDimensionPropertyBuilderImpl,RasterImpl,RasterImpl.RasterPropertyBuilderImpl
public interface GridWidthAccessorProvides an accessor for a grid width property.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceGridWidthAccessor.GridWidthBuilder<B extends GridWidthAccessor.GridWidthBuilder<B>>Provides a builder method for a grid width property returning the builder for applying multiple build operations.static interfaceGridWidthAccessor.GridWidthMutatorProvides a mutator for a grid width property.static interfaceGridWidthAccessor.GridWidthPropertyProvides a grid width property.
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description intgetGridWidth()Retrieves the grid width from the grid width property.
-