Package org.refcodes.graphical
Interface HeightAccessor
-
- All Known Subinterfaces:
Dimension,Dimension.DimensionProperty,Dimension.DimensionPropertyBuilder,HeightAccessor.HeightProperty,PixmapImageBuilder<PX>,RgbPixmapImageBuilder
- All Known Implementing Classes:
DimensionImpl,DimensionImpl.DimensionPropertyBuilderImpl,RgbPixmapImageBuilderImpl
public interface HeightAccessorProvides an accessor for a height property.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceHeightAccessor.HeightBuilder<B extends HeightAccessor.HeightBuilder<B>>Provides a builder method for a height property returning the builder for applying multiple build operations.static interfaceHeightAccessor.HeightMutatorProvides a mutator for a height property.static interfaceHeightAccessor.HeightPropertyProvides a height property.
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description intgetHeight()Retrieves the height from the height property.
-