Package org.refcodes.graphical
Interface OpacityAccessor
-
- All Known Subinterfaces:
OpacityAccessor.OpacityProperty
public interface OpacityAccessorProvides an accessor for a opacity property.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceOpacityAccessor.OpacityBuilder<B extends OpacityAccessor.OpacityBuilder<B>>Provides a builder method for a opacity property returning the builder for applying multiple build operations.static interfaceOpacityAccessor.OpacityMutatorProvides a mutator for a opacity property.static interfaceOpacityAccessor.OpacityPropertyProvides a opacity property.
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description doublegetOpacity()Retrieves the opacity from the opacity property.
-