Package org.refcodes.graphical
Interface Pixmap<PX>
-
- Type Parameters:
PX- The type of the pixel being managed by thePixmap.
- All Known Subinterfaces:
Pixmap.PixmapProperty<PX>,Pixmap.PixmapPropertyBuilder<PX,B>,RgbPixmap,RgbPixmap.RgbPixmapProperty,RgbPixmap.RgbPixmapPropertyBuilder
- All Known Implementing Classes:
RgbPixmapImpl,RgbPixmapImpl.RgbPixmapPropertyBuilderImpl
public interface Pixmap<PX>
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfacePixmap.PixmapBuilder<PX,B extends Pixmap.PixmapBuilder<PX,B>>Provides a builder method for a pixmap property returning the builder for applying multiple build operations.static interfacePixmap.PixmapMutator<PX>Provides a mutator for a pixmap property.static interfacePixmap.PixmapProperty<PX>Provides a pixmap property.static interfacePixmap.PixmapPropertyBuilder<PX,B extends Pixmap.PixmapPropertyBuilder<PX,B>>Provides a pixmap property builder.
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description PXgetPixelAt(int aPosX, int aPosY)Retrieves a pixel at a given position.PX[][]getPixels()Returns the two dimensional pixels array representing the pixmap.intgetPixmapHeight()Retrieves the height of thePixmap.intgetPixmapWidth()Retrieves the width of thePixmap.
-
-
-
Method Detail
-
getPixels
PX[][] getPixels()
Returns the two dimensional pixels array representing the pixmap.- Returns:
- The pixmap array.
-
getPixmapWidth
int getPixmapWidth()
Retrieves the width of thePixmap.- Returns:
- The width of the
Pixmap
-
getPixmapHeight
int getPixmapHeight()
Retrieves the height of thePixmap.- Returns:
- The height of the
Pixmap
-
getPixelAt
PX getPixelAt(int aPosX, int aPosY) throws java.lang.IndexOutOfBoundsException
Retrieves a pixel at a given position.- Parameters:
aPosX- The x position for the pixel to be retrieved.aPosY- The y position for the pixel to be retrieved.- Returns:
- The according pixel
- Throws:
java.lang.IndexOutOfBoundsException- in case the index is out of bounds.
-
-