Package org.refcodes.graphical
Interface Pixmap.PixmapMutator<PX>
-
- Type Parameters:
PX- the generic type
- All Known Subinterfaces:
Pixmap.PixmapProperty<PX>,Pixmap.PixmapPropertyBuilder<PX,B>,RgbPixmap.RgbPixmapMutator,RgbPixmap.RgbPixmapProperty,RgbPixmap.RgbPixmapPropertyBuilder
- All Known Implementing Classes:
RgbPixmapImpl.RgbPixmapPropertyBuilderImpl
public static interface Pixmap.PixmapMutator<PX>Provides a mutator for a pixmap property.
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description voidsetPixelAt(PX aPixel, int aPosX, int aPosY)Sets a pixel in the pixmap.voidsetPixels(PX[][] aPixels)Sets the pixels.
-
-
-
Method Detail
-
setPixelAt
void setPixelAt(PX aPixel, int aPosX, int aPosY) throws java.lang.IndexOutOfBoundsException
Sets a pixel in the pixmap.- Parameters:
aPixel- The pixel to be placed at the given position.aPosX- The x position of the pixel.aPosY- The y position of the pixel.- Throws:
java.lang.IndexOutOfBoundsException- in case the index is out of bounds.
-
setPixels
void setPixels(PX[][] aPixels)
Sets the pixels.- Parameters:
aPixels- the new pixels
-
-