Package org.refcodes.graphical
Interface PosYAccessor
-
- All Known Subinterfaces:
Position,Position.PositionProperty,Position.PositionPropertyBuilder,PosYAccessor.PosYProperty
- All Known Implementing Classes:
PositionImpl,PositionImpl.PositionPropertyBuilderImpl
public interface PosYAccessorProvides an accessor for a Y position property.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfacePosYAccessor.PosYBuilder<B extends PosYAccessor.PosYBuilder<B>>Provides a builder method for a Y position property returning the builder for applying multiple build operations.static interfacePosYAccessor.PosYMutatorProvides a mutator for a Y position property.static interfacePosYAccessor.PosYPropertyProvides a Y position property.
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description intgetPositionY()Retrieves the Y position from the Y position property.
-