Package org.refcodes.graphical
Class PositionImpl.PositionPropertyBuilderImpl
- java.lang.Object
-
- org.refcodes.graphical.PositionImpl
-
- org.refcodes.graphical.PositionImpl.PositionPropertyBuilderImpl
-
- All Implemented Interfaces:
Position,Position.PositionBuilder<Position.PositionPropertyBuilder>,Position.PositionMutator,Position.PositionProperty,Position.PositionPropertyBuilder,PosXAccessor,PosXAccessor.PosXBuilder<Position.PositionPropertyBuilder>,PosXAccessor.PosXMutator,PosXAccessor.PosXProperty,PosYAccessor,PosYAccessor.PosYBuilder<Position.PositionPropertyBuilder>,PosYAccessor.PosYMutator,PosYAccessor.PosYProperty
- Enclosing class:
- PositionImpl
public static class PositionImpl.PositionPropertyBuilderImpl extends PositionImpl implements Position.PositionPropertyBuilder
The Class PositionPropertyBuilderImpl.
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.graphical.Position
Position.PositionBuilder<B extends Position.PositionBuilder<B>>, Position.PositionMutator, Position.PositionProperty, Position.PositionPropertyBuilder
-
Nested classes/interfaces inherited from class org.refcodes.graphical.PositionImpl
PositionImpl.PositionPropertyBuilderImpl
-
Nested classes/interfaces inherited from interface org.refcodes.graphical.PosXAccessor
PosXAccessor.PosXBuilder<B extends PosXAccessor.PosXBuilder<B>>, PosXAccessor.PosXMutator, PosXAccessor.PosXProperty
-
Nested classes/interfaces inherited from interface org.refcodes.graphical.PosYAccessor
PosYAccessor.PosYBuilder<B extends PosYAccessor.PosYBuilder<B>>, PosYAccessor.PosYMutator, PosYAccessor.PosYProperty
-
-
Field Summary
-
Fields inherited from class org.refcodes.graphical.PositionImpl
_posX, _posY
-
-
Constructor Summary
Constructors Constructor Description PositionPropertyBuilderImpl()Instantiates a new position property builder impl.PositionPropertyBuilderImpl(int aPosX, int aPosY)Instantiates a new position property builder impl.
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description voidsetPosition(int aPosX, int aPosY)Sets the position.voidsetPosition(Position aPosition)Sets the position.voidsetPositionX(int aPosX)Sets the X position for the X position property.voidsetPositionY(int aPosY)Sets the Y position for the Y position property.PositionImpl.PositionPropertyBuilderImplwithPosition(int aPosX, int aPosY)With position.PositionImpl.PositionPropertyBuilderImplwithPosition(Position aPosition)With position.PositionImpl.PositionPropertyBuilderImplwithPositionX(int aPosX)Sets the X position for the X position property.PositionImpl.PositionPropertyBuilderImplwithPositionY(int aPosY)Sets the Y position for the Y position property.-
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface org.refcodes.graphical.Position.PositionProperty
addTo, subFrom
-
Methods inherited from class org.refcodes.graphical.PositionImpl
getPositionX, getPositionY, toString
-
Methods inherited from interface org.refcodes.graphical.PosXAccessor
getPositionX
-
Methods inherited from interface org.refcodes.graphical.PosYAccessor
getPositionY
-
-
-
-
Constructor Detail
-
PositionPropertyBuilderImpl
public PositionPropertyBuilderImpl()
Instantiates a new position property builder impl.
-
PositionPropertyBuilderImpl
public PositionPropertyBuilderImpl(int aPosX, int aPosY)Instantiates a new position property builder impl.- Parameters:
aPosX- the pos XaPosY- the pos Y
-
-
Method Detail
-
setPositionX
public void setPositionX(int aPosX)
Sets the X position for the X position property.- Specified by:
setPositionXin interfacePosXAccessor.PosXMutator- Parameters:
aPosX- The X position to be stored by the X position property.
-
withPositionX
public PositionImpl.PositionPropertyBuilderImpl withPositionX(int aPosX)
Sets the X position for the X position property.- Specified by:
withPositionXin interfacePosXAccessor.PosXBuilder<Position.PositionPropertyBuilder>- Parameters:
aPosX- The X position to be stored by the X position property.- Returns:
- The builder for applying multiple build operations.
-
setPositionY
public void setPositionY(int aPosY)
Sets the Y position for the Y position property.- Specified by:
setPositionYin interfacePosYAccessor.PosYMutator- Parameters:
aPosY- The Y position to be stored by the Y position property.
-
withPositionY
public PositionImpl.PositionPropertyBuilderImpl withPositionY(int aPosY)
Sets the Y position for the Y position property.- Specified by:
withPositionYin interfacePosYAccessor.PosYBuilder<Position.PositionPropertyBuilder>- Parameters:
aPosY- The Y position to be stored by the Y position property.- Returns:
- The builder for applying multiple build operations.
-
withPosition
public PositionImpl.PositionPropertyBuilderImpl withPosition(int aPosX, int aPosY)
With position.- Specified by:
withPositionin interfacePosition.PositionBuilder<Position.PositionPropertyBuilder>- Parameters:
aPosX- the pos XaPosY- the pos Y- Returns:
- the b
-
withPosition
public PositionImpl.PositionPropertyBuilderImpl withPosition(Position aPosition)
With position.- Specified by:
withPositionin interfacePosition.PositionBuilder<Position.PositionPropertyBuilder>- Parameters:
aPosition- the position- Returns:
- the b
-
setPosition
public void setPosition(int aPosX, int aPosY)Sets the position.- Specified by:
setPositionin interfacePosition.PositionMutator- Parameters:
aPosX- the pos XaPosY- the pos Y
-
setPosition
public void setPosition(Position aPosition)
Sets the position.- Specified by:
setPositionin interfacePosition.PositionMutator- Parameters:
aPosition- the new position
-
-