Package org.refcodes.graphical
Class RgbPixmapImageBuilderImpl
- java.lang.Object
-
- org.refcodes.graphical.RgbPixmapImageBuilderImpl
-
- All Implemented Interfaces:
BuildPixmap<RgbPixel>,Dimension,Dimension.DimensionBuilder<RgbPixel>,Dimension.DimensionMutator,Dimension.DimensionProperty,HeightAccessor,HeightAccessor.HeightBuilder<RgbPixel>,HeightAccessor.HeightMutator,HeightAccessor.HeightProperty,PixmapImageBuilder<RgbPixel>,RgbPixmapImageBuilder,WidthAccessor,WidthAccessor.WidthBuilder<RgbPixel>,WidthAccessor.WidthMutator,WidthAccessor.WidthProperty
public class RgbPixmapImageBuilderImpl extends java.lang.Object implements RgbPixmapImageBuilder
The Class RgbPixmapImageBuilderImpl.- Author:
- steiner
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.graphical.Dimension
Dimension.DimensionBuilder<B extends Dimension.DimensionBuilder<B>>, Dimension.DimensionMutator, Dimension.DimensionProperty, Dimension.DimensionPropertyBuilder
-
Nested classes/interfaces inherited from interface org.refcodes.graphical.HeightAccessor
HeightAccessor.HeightBuilder<B extends HeightAccessor.HeightBuilder<B>>, HeightAccessor.HeightMutator, HeightAccessor.HeightProperty
-
Nested classes/interfaces inherited from interface org.refcodes.graphical.WidthAccessor
WidthAccessor.WidthBuilder<B extends WidthAccessor.WidthBuilder<B>>, WidthAccessor.WidthMutator, WidthAccessor.WidthProperty
-
-
Constructor Summary
Constructors Constructor Description RgbPixmapImageBuilderImpl()
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description intgetHeight()Retrieves the height from the height property.intgetWidth()Retrieves the width from the width property.voidsetDimension(int aWidth, int aHeight)Sets the dimension.voidsetDimension(Dimension aDimension)Sets the dimension.voidsetHeight(int aHeight)Sets the height for the height property.voidsetImageInputStream(java.io.InputStream aImageStream)Sets theInputStreamfor retrieving the image data for the image property.voidsetImageURL(java.net.URL aImageUrl)Sets theURLfor retrieving the image data for the image property.voidsetWidth(int aWidth)Sets the width for the width property.RgbPixmaptoPixmap()To pixmap.RgbPixmaptoPixmap(java.io.InputStream aImageStream)To pixmap.RgbPixmaptoPixmap(java.net.URL aImageUrl)To pixmap.protected static RgbPixmaptoPixmap(javafx.scene.image.Image aImage)To pixmap.RgbPixmapImageBuilderwithDimension(int aWidth, int aHeight)With dimension.RgbPixmapImageBuilderwithDimension(Dimension aDimension)With dimension.RgbPixmapImageBuilderwithHeight(int aHeight)Sets the height for the height property.RgbPixmapImageBuilderwithWidth(int aWidth)Sets the width for the width property.-
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
Methods inherited from interface org.refcodes.graphical.PixmapImageBuilder
setImageFile
-
Methods inherited from interface org.refcodes.graphical.RgbPixmapImageBuilder
toPixmap, withImageFile, withImageInputStream, withImageURL
-
-
-
-
Method Detail
-
getWidth
public int getWidth()
Retrieves the width from the width property.- Specified by:
getWidthin interfaceWidthAccessor- Returns:
- The width stored by the width property.
-
getHeight
public int getHeight()
Retrieves the height from the height property.- Specified by:
getHeightin interfaceHeightAccessor- Returns:
- The height stored by the height property.
-
setDimension
public void setDimension(int aWidth, int aHeight)Sets the dimension.- Specified by:
setDimensionin interfaceDimension.DimensionMutator- Parameters:
aWidth- the widthaHeight- the height
-
setDimension
public void setDimension(Dimension aDimension)
Sets the dimension.- Specified by:
setDimensionin interfaceDimension.DimensionMutator- Parameters:
aDimension- the new dimension
-
setWidth
public void setWidth(int aWidth)
Sets the width for the width property.- Specified by:
setWidthin interfaceWidthAccessor.WidthMutator- Parameters:
aWidth- The width to be stored by the width property.
-
setHeight
public void setHeight(int aHeight)
Sets the height for the height property.- Specified by:
setHeightin interfaceHeightAccessor.HeightMutator- Parameters:
aHeight- The height to be stored by the height property.
-
withDimension
public RgbPixmapImageBuilder withDimension(int aWidth, int aHeight)
With dimension.- Specified by:
withDimensionin interfaceDimension.DimensionBuilder<RgbPixel>- Specified by:
withDimensionin interfaceRgbPixmapImageBuilder- Parameters:
aWidth- the widthaHeight- the height- Returns:
- the b
-
withDimension
public RgbPixmapImageBuilder withDimension(Dimension aDimension)
With dimension.- Specified by:
withDimensionin interfaceDimension.DimensionBuilder<RgbPixel>- Specified by:
withDimensionin interfaceRgbPixmapImageBuilder- Parameters:
aDimension- the dimension- Returns:
- the b
-
withWidth
public RgbPixmapImageBuilder withWidth(int aWidth)
Sets the width for the width property.- Specified by:
withWidthin interfaceRgbPixmapImageBuilder- Specified by:
withWidthin interfaceWidthAccessor.WidthBuilder<RgbPixel>- Parameters:
aWidth- The width to be stored by the width property.- Returns:
- The builder for applying multiple build operations.
-
withHeight
public RgbPixmapImageBuilder withHeight(int aHeight)
Sets the height for the height property.- Specified by:
withHeightin interfaceHeightAccessor.HeightBuilder<RgbPixel>- Specified by:
withHeightin interfaceRgbPixmapImageBuilder- Parameters:
aHeight- The height to be stored by the height property.- Returns:
- The builder for applying multiple build operations.
-
setImageInputStream
public void setImageInputStream(java.io.InputStream aImageStream)
Sets theInputStreamfor retrieving the image data for the image property.- Specified by:
setImageInputStreamin interfacePixmapImageBuilder<RgbPixel>- Parameters:
aImageStream- The image which'sInputStreamis to be stored by the imageInputStreamproperty.
-
setImageURL
public void setImageURL(java.net.URL aImageUrl)
Sets theURLfor retrieving the image data for the image property.- Specified by:
setImageURLin interfacePixmapImageBuilder<RgbPixel>- Parameters:
aImageUrl- The image which'sURLis to be stored by the imageURLproperty.
-
toPixmap
public RgbPixmap toPixmap()
To pixmap.- Specified by:
toPixmapin interfaceBuildPixmap<RgbPixel>- Specified by:
toPixmapin interfaceRgbPixmapImageBuilder- Returns:
- the pixmap
-
toPixmap
public RgbPixmap toPixmap(java.net.URL aImageUrl)
To pixmap.- Specified by:
toPixmapin interfaceRgbPixmapImageBuilder- Parameters:
aImageUrl- the image url- Returns:
- the rgb pixmap
-
toPixmap
public RgbPixmap toPixmap(java.io.InputStream aImageStream)
To pixmap.- Specified by:
toPixmapin interfaceRgbPixmapImageBuilder- Parameters:
aImageStream- the image stream- Returns:
- the rgb pixmap
-
toPixmap
protected static RgbPixmap toPixmap(javafx.scene.image.Image aImage)
To pixmap.- Parameters:
aImage- the image- Returns:
- the rgb pixmap
-
-