Package org.refcodes.graphical
Interface VectorYAccessor
-
- All Known Subinterfaces:
Vector,Vector.VectorProperty,Vector.VectorPropertyBuilder,VectorYAccessor.VectorYProperty
public interface VectorYAccessorProvides an accessor for a Y vector property.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceVectorYAccessor.VectorYBuilder<B extends VectorYAccessor.VectorYBuilder<B>>Provides a builder method for a Y vector property returning the builder for applying multiple build operations.static interfaceVectorYAccessor.VectorYMutatorProvides a mutator for a Y vector property.static interfaceVectorYAccessor.VectorYPropertyProvides a Y vector property.
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description intgetVectorY()Retrieves the Y vector from the Y vector property.
-