Package org.refcodes.graphical
Interface VectorYAccessor.VectorYMutator
-
- All Known Subinterfaces:
Vector.VectorMutator,Vector.VectorProperty,Vector.VectorPropertyBuilder,VectorYAccessor.VectorYProperty
- Enclosing interface:
- VectorYAccessor
public static interface VectorYAccessor.VectorYMutatorProvides a mutator for a Y vector property.
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description voidsetVectorY(int aVectorY)Sets the Y vector for the Y vector property.
-