Package org.refcodes.graphical
Interface ViewportWidthAccessor
-
- All Known Subinterfaces:
ViewportDimension,ViewportDimension.ViewportDimensionProperty,ViewportDimension.ViewportDimensionPropertyBuilderBuilder,ViewportPane<B>,ViewportWidthAccessor.ViewportWidthProperty
- All Known Implementing Classes:
ViewportDimensionImpl,ViewportDimensionImpl.ViewportDimensionPropertyBuilderImpl
public interface ViewportWidthAccessorProvides an accessor for a viewport width property.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceViewportWidthAccessor.ViewportWidthBuilder<B extends ViewportWidthAccessor.ViewportWidthBuilder<B>>Provides a builder method for a viewport width property returning the builder for applying multiple build operations.static interfaceViewportWidthAccessor.ViewportWidthMutatorProvides a mutator for a viewport width property.static interfaceViewportWidthAccessor.ViewportWidthPropertyProvides a viewport width property.
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description intgetViewportWidth()Retrieves the viewport width from the viewport width property.
-