Package org.refcodes.graphical
Interface WidthAccessor
-
- All Known Subinterfaces:
Dimension,Dimension.DimensionProperty,Dimension.DimensionPropertyBuilder,PixmapImageBuilder<PX>,RgbPixmapImageBuilder,WidthAccessor.WidthProperty
- All Known Implementing Classes:
DimensionImpl,DimensionImpl.DimensionPropertyBuilderImpl,RgbPixmapImageBuilderImpl
public interface WidthAccessorProvides an accessor for a width property.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceWidthAccessor.WidthBuilder<B extends WidthAccessor.WidthBuilder<B>>Provides a builder method for a width property returning the builder for applying multiple build operations.static interfaceWidthAccessor.WidthMutatorProvides a mutator for a width property.static interfaceWidthAccessor.WidthPropertyProvides a width property.
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description intgetWidth()Retrieves the width from the width property.
-