Uses of Class
org.refcodes.graphical.BoxBorderMode
-
-
Uses of BoxBorderMode in org.refcodes.graphical
Methods in org.refcodes.graphical that return BoxBorderMode Modifier and Type Method Description static BoxBorderModeBoxBorderMode. fromBoxBorders(boolean isTopBorder, boolean isRightBorder, boolean isBottomBorder, boolean isLeftBorder)From box borders.BoxBorderModeBoxBorderModeAccessor. getBoxBorderMode()Retrieves the box border mode from the box border mode property.static BoxBorderModeBoxBorderMode. valueOf(java.lang.String name)Returns the enum constant of this type with the specified name.static BoxBorderMode[]BoxBorderMode. values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in org.refcodes.graphical with parameters of type BoxBorderMode Modifier and Type Method Description voidBoxBorderModeAccessor.BoxBorderModeMutator. setBoxBorderMode(BoxBorderMode aBoxBorderMode)Sets the box border mode for the box border mode property.BBoxBorderModeAccessor.BoxBorderModeBuilder. withBoxBorderMode(BoxBorderMode aBoxBorderMode)Sets the box border mode for the box border mode property.
-