Uses of Class
org.refcodes.graphical.LayoutMode
-
-
Uses of LayoutMode in org.refcodes.graphical
Methods in org.refcodes.graphical that return LayoutMode Modifier and Type Method Description LayoutModeLayoutModeAccessor. getLayoutMode()Retrieves the layout mode from the layout mode property.static LayoutModeLayoutMode. valueOf(java.lang.String name)Returns the enum constant of this type with the specified name.static LayoutMode[]LayoutMode. values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in org.refcodes.graphical with parameters of type LayoutMode Modifier and Type Method Description voidLayoutModeAccessor.LayoutModeMutator. setLayoutMode(LayoutMode aLayoutMode)Sets the layout mode for the layout mode property.BLayoutModeAccessor.LayoutModeBuilder. withLayoutMode(LayoutMode aLayoutMode)Sets the layout mode for the layout mode property.
-