Uses of Class
org.refcodes.graphical.MoveMode
-
-
Uses of MoveMode in org.refcodes.graphical
Methods in org.refcodes.graphical that return MoveMode Modifier and Type Method Description MoveModeMoveModeAccessor. getMoveMode()Retrieves the move mode from the move mode property.static MoveModeMoveMode. valueOf(java.lang.String name)Returns the enum constant of this type with the specified name.static MoveMode[]MoveMode. values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in org.refcodes.graphical with parameters of type MoveMode Modifier and Type Method Description voidMoveModeAccessor.MoveModeMutator. setMoveMode(MoveMode aMoveMode)Sets the move mode for the move mode property.BMoveModeAccessor.MoveModeBuilder. withMoveMode(MoveMode aMoveMode)Sets the move mode for the move mode property.
-