Uses of Class
org.refcodes.graphical.ScaleMode
-
-
Uses of ScaleMode in org.refcodes.graphical
Methods in org.refcodes.graphical that return ScaleMode Modifier and Type Method Description ScaleModeScaleModeAccessor. getScaleMode()Retrieves the scale mode from the scale mode property.static ScaleModeScaleMode. valueOf(java.lang.String name)Returns the enum constant of this type with the specified name.static ScaleMode[]ScaleMode. values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in org.refcodes.graphical with parameters of type ScaleMode Modifier and Type Method Description voidScaleModeAccessor.ScaleModeMutator. setScaleMode(ScaleMode aScaleMode)Sets the scale mode for the scale mode property.BScaleModeAccessor.ScaleModeBuilder. withScaleMode(ScaleMode aScaleMode)Sets the scale mode for the scale mode property.
-