Module org.refcodes.graphical
Package org.refcodes.graphical
Interface BackgroundAccessor.BackgroundProperty<T>
-
- Type Parameters:
T- The background's type to be accessed.
- All Superinterfaces:
BackgroundAccessor<T>,BackgroundAccessor.BackgroundMutator<T>
- Enclosing interface:
- BackgroundAccessor<T>
public static interface BackgroundAccessor.BackgroundProperty<T> extends BackgroundAccessor<T>, BackgroundAccessor.BackgroundMutator<T>
Provides a background property.
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.graphical.BackgroundAccessor
BackgroundAccessor.BackgroundBuilder<T,B extends BackgroundAccessor.BackgroundBuilder<T,B>>, BackgroundAccessor.BackgroundMutator<T>, BackgroundAccessor.BackgroundProperty<T>
-
-
Method Summary
All Methods Instance Methods Default Methods Modifier and Type Method Description default TletBackground(T aBackground)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the given background (setter) as ofBackgroundAccessor.BackgroundMutator.setBackground(Object)and returns the very same value (getter).-
Methods inherited from interface org.refcodes.graphical.BackgroundAccessor
getBackground
-
Methods inherited from interface org.refcodes.graphical.BackgroundAccessor.BackgroundMutator
setBackground
-
-
-
-
Method Detail
-
letBackground
default T letBackground(T aBackground)
This method stores and passes through the given argument, which is very useful for builder APIs: Sets the given background (setter) as ofBackgroundAccessor.BackgroundMutator.setBackground(Object)and returns the very same value (getter).- Parameters:
aBackground- The background to set (viaBackgroundAccessor.BackgroundMutator.setBackground(Object)).- Returns:
- Returns the value passed for it to be used in conclusive processing steps.
-
-