Module org.refcodes.graphical
Package org.refcodes.graphical
Interface ContainerWidthAccessor.ContainerWidthMutator
- All Known Subinterfaces:
ContainerDimension.ContainerDimensionMutator,ContainerDimension.ContainerDimensionProperty,ContainerWidthAccessor.ContainerWidthProperty
- Enclosing interface:
- ContainerWidthAccessor
public static interface ContainerWidthAccessor.ContainerWidthMutator
Provides a mutator for a container width property.
-
Method Summary
Modifier and TypeMethodDescriptionvoidsetContainerWidth(int aWidth) Sets the container width for the container width property.
-
Method Details
-
setContainerWidth
void setContainerWidth(int aWidth) Sets the container width for the container width property.- Parameters:
aWidth- The container width to be stored by the container width property.
-