java.lang.Object
org.refcodes.graphical.FieldDimensionImpl
- All Implemented Interfaces:
FieldDimension,FieldGapAccessor,FieldHeightAccessor,FieldWidthAccessor
The Class FieldDimensionImpl.
- Author:
- steiner
-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.graphical.FieldDimension
FieldDimension.FieldDimensionAccessor, FieldDimension.FieldDimensionBuilder<B extends FieldDimension.FieldDimensionBuilder<B>>, FieldDimension.FieldDimensionMutator, FieldDimension.FieldDimensionPropertyNested classes/interfaces inherited from interface org.refcodes.graphical.FieldGapAccessor
FieldGapAccessor.FieldGapBuilder<B extends FieldGapAccessor.FieldGapBuilder<B>>, FieldGapAccessor.FieldGapMutator, FieldGapAccessor.FieldGapPropertyNested classes/interfaces inherited from interface org.refcodes.graphical.FieldHeightAccessor
FieldHeightAccessor.FieldHeightBuilder<B extends FieldHeightAccessor.FieldHeightBuilder<B>>, FieldHeightAccessor.FieldHeightMutator, FieldHeightAccessor.FieldHeightPropertyNested classes/interfaces inherited from interface org.refcodes.graphical.FieldWidthAccessor
FieldWidthAccessor.FieldWidthBuilder<B extends FieldWidthAccessor.FieldWidthBuilder<B>>, FieldWidthAccessor.FieldWidthMutator, FieldWidthAccessor.FieldWidthProperty -
Field Summary
FieldsModifier and TypeFieldDescriptionprotected intprotected intprotected int -
Constructor Summary
ConstructorsModifierConstructorDescriptionprotectedInstantiates a new field dimension impl.FieldDimensionImpl(int aWidth, int aHeight, int aFieldGap) Instantiates a new field dimension impl. -
Method Summary
Modifier and TypeMethodDescriptionintRetrieves the field gap from the field gap property.intRetrieves the field height from the field height property.intRetrieves the field width from the field width property.toString()
-
Field Details
-
_fieldWidth
protected int _fieldWidth -
_fieldHeight
protected int _fieldHeight -
_fieldGap
protected int _fieldGap
-
-
Constructor Details
-
FieldDimensionImpl
protected FieldDimensionImpl()Instantiates a new field dimension impl. -
FieldDimensionImpl
public FieldDimensionImpl(int aWidth, int aHeight, int aFieldGap) Instantiates a new field dimension impl.- Parameters:
aWidth- the widthaHeight- the heightaFieldGap- the field gap
-
-
Method Details
-
getFieldWidth
public int getFieldWidth()Retrieves the field width from the field width property.- Specified by:
getFieldWidthin interfaceFieldWidthAccessor- Returns:
- The field width stored by the field width property.
-
getFieldHeight
public int getFieldHeight()Retrieves the field height from the field height property.- Specified by:
getFieldHeightin interfaceFieldHeightAccessor- Returns:
- The field height stored by the field height property.
-
getFieldGap
public int getFieldGap()Retrieves the field gap from the field gap property.- Specified by:
getFieldGapin interfaceFieldGapAccessor- Returns:
- The field gap stored by the field gap property.
-
toString
-