- All Known Subinterfaces:
FieldDimension,FieldDimension.FieldDimensionAccessor,FieldDimension.FieldDimensionProperty,FieldHeightAccessor.FieldHeightProperty,GridViewportPane<C,,B> Raster,Raster.RasterAccessor,Raster.RasterProperty
- All Known Implementing Classes:
FieldDimensionImpl,RasterImpl,RasterPropertyBuilder
public interface FieldHeightAccessor
Provides an accessor for a field height property.
-
Nested Class Summary
Nested ClassesModifier and TypeInterfaceDescriptionstatic interfaceProvides a builder method for a field height property returning the builder for applying multiple build operations.static interfaceProvides a mutator for a field height property.static interfaceProvides a field height property. -
Method Summary
Modifier and TypeMethodDescriptionintRetrieves the field height from the field height property.
-
Method Details
-
getFieldHeight
int getFieldHeight()Retrieves the field height from the field height property.- Returns:
- The field height stored by the field height property.
-