-
- All Known Subinterfaces:
FieldDimension,FieldDimension.FieldDimensionProperty,FieldHeightAccessor.FieldHeightProperty,Raster,Raster.RasterProperty,ViewportPane<C,B>
- All Known Implementing Classes:
FieldDimensionImpl,RasterImpl,RasterPropertyBuilder
public interface FieldHeightAccessorProvides an accessor for a field height property.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceFieldHeightAccessor.FieldHeightBuilder<B extends FieldHeightAccessor.FieldHeightBuilder<B>>Provides a builder method for a field height property returning the builder for applying multiple build operations.static interfaceFieldHeightAccessor.FieldHeightMutatorProvides a mutator for a field height property.static interfaceFieldHeightAccessor.FieldHeightPropertyProvides a field height property.
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description intgetFieldHeight()Retrieves the field height from the field height property.
-