- java.lang.Object
-
- org.refcodes.graphical.GridDimensionImpl
-
- All Implemented Interfaces:
GridDimension,GridHeightAccessor,GridWidthAccessor
public class GridDimensionImpl extends Object implements GridDimension
The Class GridDimensionImpl.- Author:
- steiner
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.graphical.GridDimension
GridDimension.GridDimensionBuilder<B extends GridDimension.GridDimensionBuilder<B>>, GridDimension.GridDimensionMutator, GridDimension.GridDimensionProperty
-
Nested classes/interfaces inherited from interface org.refcodes.graphical.GridHeightAccessor
GridHeightAccessor.GridHeightBuilder<B extends GridHeightAccessor.GridHeightBuilder<B>>, GridHeightAccessor.GridHeightMutator, GridHeightAccessor.GridHeightProperty
-
Nested classes/interfaces inherited from interface org.refcodes.graphical.GridWidthAccessor
GridWidthAccessor.GridWidthBuilder<B extends GridWidthAccessor.GridWidthBuilder<B>>, GridWidthAccessor.GridWidthMutator, GridWidthAccessor.GridWidthProperty
-
-
Constructor Summary
Constructors Modifier Constructor Description protectedGridDimensionImpl()Instantiates a new grid dimension impl.GridDimensionImpl(int aWidth, int aHeight)Instantiates a new grid dimension impl.
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description intgetGridHeight()Retrieves the grid height from the grid height property.intgetGridWidth()Retrieves the grid width from the grid width property.StringtoString()-
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface org.refcodes.graphical.GridDimension
isInBounds, isInBounds, isInHeight, isInWidth
-
-
-
-
Method Detail
-
getGridWidth
public int getGridWidth()
Retrieves the grid width from the grid width property.- Specified by:
getGridWidthin interfaceGridWidthAccessor- Returns:
- The grid width stored by the grid width property.
-
getGridHeight
public int getGridHeight()
Retrieves the grid height from the grid height property.- Specified by:
getGridHeightin interfaceGridHeightAccessor- Returns:
- The grid height stored by the grid height property.
-
-