- All Known Subinterfaces:
GridModeAccessor.GridModeProperty,Raster,Raster.RasterProperty,ViewportPane<C,B>
- All Known Implementing Classes:
RasterImpl,RasterPropertyBuilder
public interface GridModeAccessor
Provides an accessor for a grid mode property.
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceGridModeAccessor.GridModeBuilder<B extends GridModeAccessor.GridModeBuilder<B>>Provides a builder method for a grid mode property returning the builder for applying multiple build operations.static interfaceGridModeAccessor.GridModeMutatorProvides a mutator for a grid mode property.static interfaceGridModeAccessor.GridModePropertyProvides a grid mode property. -
Method Summary
Modifier and Type Method Description GridModegetGridMode()Retrieves the grid mode from the grid mode property.
-
Method Details
-
getGridMode
GridMode getGridMode()Retrieves the grid mode from the grid mode property.- Returns:
- The grid mode stored by the grid mode property.
-