Module org.refcodes.graphical
Package org.refcodes.graphical
Interface LeftPaddingAccessor.LeftPaddingMutator
- All Known Subinterfaces:
LeftPaddingAccessor.LeftPaddingProperty,Padding.PaddingMutator,Padding.PaddingProperty
- Enclosing interface:
- LeftPaddingAccessor
public static interface LeftPaddingAccessor.LeftPaddingMutator
Provides a mutator for a left padding property.
-
Method Summary
Modifier and TypeMethodDescriptionvoidsetLeftPadding(int aLeftPadding) Sets the left padding for the left padding property.
-
Method Details
-
setLeftPadding
void setLeftPadding(int aLeftPadding) Sets the left padding for the left padding property.- Parameters:
aLeftPadding- The left padding to be stored by the left padding property.
-