Interface LeftPaddingAccessor.LeftPaddingProperty
- All Superinterfaces:
LeftPaddingAccessor,LeftPaddingAccessor.LeftPaddingMutator
- All Known Subinterfaces:
Padding.PaddingProperty
- Enclosing interface:
LeftPaddingAccessor
public static interface LeftPaddingAccessor.LeftPaddingProperty
extends LeftPaddingAccessor, LeftPaddingAccessor.LeftPaddingMutator
Provides a left padding property.
-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.graphical.LeftPaddingAccessor
LeftPaddingAccessor.LeftPaddingBuilder<B extends LeftPaddingAccessor.LeftPaddingBuilder<B>>, LeftPaddingAccessor.LeftPaddingMutator, LeftPaddingAccessor.LeftPaddingProperty -
Method Summary
Modifier and TypeMethodDescriptiondefault intletLeftPadding(int aLeftPadding) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the given integer (setter) as ofLeftPaddingAccessor.LeftPaddingMutator.setLeftPadding(int)and returns the very same value (getter).Methods inherited from interface org.refcodes.graphical.LeftPaddingAccessor
getLeftPaddingMethods inherited from interface org.refcodes.graphical.LeftPaddingAccessor.LeftPaddingMutator
setLeftPadding
-
Method Details
-
letLeftPadding
default int letLeftPadding(int aLeftPadding) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the given integer (setter) as ofLeftPaddingAccessor.LeftPaddingMutator.setLeftPadding(int)and returns the very same value (getter).- Parameters:
aLeftPadding- The integer to set (viaLeftPaddingAccessor.LeftPaddingMutator.setLeftPadding(int)).- Returns:
- Returns the value passed for it to be used in conclusive processing steps.
-