Nested Class Summary
Nested Classes
static interface
Provides a builder method for a pixmap property returning the builder for
applying multiple build operations.
static interface
Provides a mutator for a pixmap property.
static interface
Provides a pixmap property.
Method Summary
All Methods Instance Methods Abstract Methods Default Methods
int
Retrieves the height of the
Pixmap.
Retrieves a pixel at a given position.
Returns the two dimensional pixels array representing the pixmap.
int
Retrieves the width of the
Pixmap.
default boolean
Tests whether there is a pixel at a given position.
Method Details
getPixels
Returns the two dimensional pixels array representing the pixmap.
Returns:
The pixmap array.
getPixelAt
PX getPixelAt (int aPosX,
int aPosY)
Retrieves a pixel at a given position.
Parameters:
aPosX - The x position for the pixel to be retrieved.
aPosY - The y position for the pixel to be retrieved.
Returns:
The according pixel
Throws:
IndexOutOfBoundsException - in case the index is out of bounds.
hasPixelAt
default boolean hasPixelAt (int aPosX,
int aPosY)
Tests whether there is a pixel at a given position.
Parameters:
aPosX - The x position for the pixel to be tested.
aPosY - The y position for the pixel to be tested.
Returns:
True if we have a pixel at this position.
Throws:
IndexOutOfBoundsException - in case the index is out of bounds.