-
- Type Parameters:
PX- The type of the pixel being managed by thePixmap.
- All Superinterfaces:
HeightAccessor,Pixmap<PX>,Pixmap.PixmapMutator<PX>,WidthAccessor
- All Known Subinterfaces:
Pixmap.PixmapBuilder<PX,B>,RgbPixmap.RgbPixmapBuilder,RgbPixmap.RgbPixmapProperty
- All Known Implementing Classes:
RgbPixmapBuilderImpl
public static interface Pixmap.PixmapProperty<PX> extends Pixmap<PX>, Pixmap.PixmapMutator<PX>
Provides a pixmap property.
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.graphical.HeightAccessor
HeightAccessor.HeightBuilder<B extends HeightAccessor.HeightBuilder<B>>, HeightAccessor.HeightMutator, HeightAccessor.HeightProperty
-
Nested classes/interfaces inherited from interface org.refcodes.graphical.Pixmap
Pixmap.PixmapBuilder<PX,B extends Pixmap.PixmapBuilder<PX,B>>, Pixmap.PixmapMutator<PX>, Pixmap.PixmapProperty<PX>
-
Nested classes/interfaces inherited from interface org.refcodes.graphical.WidthAccessor
WidthAccessor.WidthBuilder<B extends WidthAccessor.WidthBuilder<B>>, WidthAccessor.WidthMutator, WidthAccessor.WidthProperty
-
-
Method Summary
All Methods Instance Methods Default Methods Modifier and Type Method Description default PX[][]letPixels(PX[][] aPixels)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the given pixels (setter) as ofPixmap.PixmapMutator.setPixels(Object[][])and returns the very same value (getter).default PXletRgbAt(PX aPixel, int aPosX, int aPosY)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the given pixels (setter) as ofPixmap.PixmapMutator.setPixelAt(Object, int, int)and returns the very same value (getter).-
Methods inherited from interface org.refcodes.graphical.Pixmap
getHeight, getPixelAt, getPixels, getWidth, hasPixelAt
-
Methods inherited from interface org.refcodes.graphical.Pixmap.PixmapMutator
setPixelAt, setPixels
-
-
-
-
Method Detail
-
letPixels
default PX[][] letPixels(PX[][] aPixels)
This method stores and passes through the given argument, which is very useful for builder APIs: Sets the given pixels (setter) as ofPixmap.PixmapMutator.setPixels(Object[][])and returns the very same value (getter).- Parameters:
aPixels- The pixels to set (viaPixmap.PixmapMutator.setPixels(Object[][])).- Returns:
- Returns the value passed for it to be used in conclusive processing steps.
-
letRgbAt
default PX letRgbAt(PX aPixel, int aPosX, int aPosY)
This method stores and passes through the given argument, which is very useful for builder APIs: Sets the given pixels (setter) as ofPixmap.PixmapMutator.setPixelAt(Object, int, int)and returns the very same value (getter).- Parameters:
aPixel- The pixel to set.aPosX- The X position where to set the pixel.aPosY- The Y position where to set the pixel.- Returns:
- Returns the pixel passed for it to be used in conclusive processing steps.
-
-