Interface PixmapImageBuilder<PX>
- Type Parameters:
PX- the generic type
- All Superinterfaces:
Dimension,Dimension.DimensionAccessor,Dimension.DimensionBuilder<PixmapImageBuilder<PX>>,Dimension.DimensionMutator,Dimension.DimensionProperty,HeightAccessor,HeightAccessor.HeightBuilder<PixmapImageBuilder<PX>>,HeightAccessor.HeightMutator,HeightAccessor.HeightProperty,WidthAccessor,WidthAccessor.WidthBuilder<PixmapImageBuilder<PX>>,WidthAccessor.WidthMutator,WidthAccessor.WidthProperty
- All Known Implementing Classes:
RgbPixmapImageBuilder
public interface PixmapImageBuilder<PX>
extends Dimension.DimensionProperty, Dimension.DimensionBuilder<PixmapImageBuilder<PX>>
The Interface PixmapImageBuilder.
-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.graphical.Dimension
Dimension.DimensionAccessor, Dimension.DimensionBuilder<B extends Dimension.DimensionBuilder<B>>, Dimension.DimensionMutator, Dimension.DimensionPropertyNested classes/interfaces inherited from interface org.refcodes.graphical.HeightAccessor
HeightAccessor.HeightBuilder<B extends HeightAccessor.HeightBuilder<B>>, HeightAccessor.HeightMutator, HeightAccessor.HeightPropertyNested classes/interfaces inherited from interface org.refcodes.graphical.WidthAccessor
WidthAccessor.WidthBuilder<B extends WidthAccessor.WidthBuilder<B>>, WidthAccessor.WidthMutator, WidthAccessor.WidthProperty -
Method Summary
Modifier and TypeMethodDescriptiondefault voidsetImageFile(File aImageFile) Sets the URL for retrieving the image data for the image property.voidsetImageInputStream(InputStream aImageStream) Sets theInputStreamfor retrieving the image data for the image property.voidsetImageURL(URL aImageUrl) Sets theURLfor retrieving the image data for the image property.toPixmap()To pixmap.default PixmapImageBuilder<PX> withImageFile(File aImageFile) Sets theFilefor retrieving the image data for the image property.default PixmapImageBuilder<PX> withImageInputStream(InputStream aImageStream) Sets the input stream for retrieving the image data for the image property.default PixmapImageBuilder<PX> withImageURL(URL aUrl) Sets theURLfor retrieving the image data for the image property.Methods inherited from interface org.refcodes.graphical.Dimension.DimensionBuilder
withDimension, withDimensionMethods inherited from interface org.refcodes.graphical.Dimension.DimensionMutator
setDimension, setDimensionMethods inherited from interface org.refcodes.graphical.Dimension.DimensionProperty
letDimension, letDimensionMethods inherited from interface org.refcodes.graphical.HeightAccessor
getHeightMethods inherited from interface org.refcodes.graphical.HeightAccessor.HeightBuilder
withHeightMethods inherited from interface org.refcodes.graphical.HeightAccessor.HeightMutator
setHeightMethods inherited from interface org.refcodes.graphical.HeightAccessor.HeightProperty
letHeightMethods inherited from interface org.refcodes.graphical.WidthAccessor
getWidthMethods inherited from interface org.refcodes.graphical.WidthAccessor.WidthBuilder
withWidthMethods inherited from interface org.refcodes.graphical.WidthAccessor.WidthMutator
setWidthMethods inherited from interface org.refcodes.graphical.WidthAccessor.WidthProperty
letWidth
-
Method Details
-
toPixmap
To pixmap.- Returns:
- the pixmap
- Throws:
IOException- thrown in case of IO related problems.
-
setImageInputStream
Sets theInputStreamfor retrieving the image data for the image property.- Parameters:
aImageStream- The image which'sInputStreamis to be stored by the imageInputStreamproperty.
-
withImageInputStream
Sets the input stream for retrieving the image data for the image property.- Parameters:
aImageStream- The image which'sInputStreamis to be stored by the imageInputStreamproperty.- Returns:
- The builder for applying multiple build operations.
-
setImageURL
-
withImageURL
Sets theURLfor retrieving the image data for the image property.- Parameters:
aUrl- the URL- Returns:
- The builder for applying multiple build operations.
-
setImageFile
Sets the URL for retrieving the image data for the image property.- Parameters:
aImageFile- The image file which'sInputStreamis to be stored by the imageInputStreamproperty.- Throws:
FileNotFoundException- in case the file was not found.
-
withImageFile
Sets theFilefor retrieving the image data for the image property.- Parameters:
aImageFile- The image file which'sInputStreamis to be stored by the imageInputStreamproperty.- Returns:
- The builder for applying multiple build operations.
- Throws:
FileNotFoundException- in case the file was not found.
-