-
- All Known Subinterfaces:
Position,Position.PositionProperty,PosXAccessor.PosXProperty,Rectangle,Rectangle.RectangleProperty
- All Known Implementing Classes:
PositionImpl,PositionPropertyBuilder,RectangleImpl
public interface PosXAccessorProvides an accessor for a X position property.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfacePosXAccessor.PosXBuilder<B extends PosXAccessor.PosXBuilder<B>>Provides a builder method for a X position property returning the builder for applying multiple build operations.static interfacePosXAccessor.PosXMutatorProvides a mutator for a X position property.static interfacePosXAccessor.PosXPropertyProvides a X position property.
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description intgetPositionX()Retrieves the X position from the X position property.
-