- java.lang.Object
-
- org.refcodes.graphical.PositionImpl
-
- All Implemented Interfaces:
Position,PosXAccessor,PosYAccessor
- Direct Known Subclasses:
PositionPropertyBuilder
public class PositionImpl extends Object implements Position
The Class PositionImpl.- Author:
- steiner
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.graphical.Position
Position.PositionBuilder<B extends Position.PositionBuilder<B>>, Position.PositionMutator, Position.PositionProperty
-
Nested classes/interfaces inherited from interface org.refcodes.graphical.PosXAccessor
PosXAccessor.PosXBuilder<B extends PosXAccessor.PosXBuilder<B>>, PosXAccessor.PosXMutator, PosXAccessor.PosXProperty
-
Nested classes/interfaces inherited from interface org.refcodes.graphical.PosYAccessor
PosYAccessor.PosYBuilder<B extends PosYAccessor.PosYBuilder<B>>, PosYAccessor.PosYMutator, PosYAccessor.PosYProperty
-
-
Constructor Summary
Constructors Modifier Constructor Description protectedPositionImpl()Instantiates a new position impl.PositionImpl(int aPosX, int aPosY)Instantiates a new position impl.
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description booleanequals(Object obj)intgetPositionX()Retrieves the X position from the X position property.intgetPositionY()Retrieves the Y position from the Y position property.inthashCode()StringtoString()
-
-
-
Method Detail
-
getPositionX
public int getPositionX()
Retrieves the X position from the X position property.- Specified by:
getPositionXin interfacePosXAccessor- Returns:
- The X position stored by the X position property.
-
getPositionY
public int getPositionY()
Retrieves the Y position from the Y position property.- Specified by:
getPositionYin interfacePosYAccessor- Returns:
- The Y position stored by the Y position property.
-
-