- java.lang.Object
-
- org.refcodes.graphical.PositionImpl
-
- org.refcodes.graphical.PositionPropertyBuilder
-
- All Implemented Interfaces:
Position,Position.PositionBuilder<PositionPropertyBuilder>,Position.PositionMutator,Position.PositionProperty,PosXAccessor,PosXAccessor.PosXBuilder<PositionPropertyBuilder>,PosXAccessor.PosXMutator,PosXAccessor.PosXProperty,PosYAccessor,PosYAccessor.PosYBuilder<PositionPropertyBuilder>,PosYAccessor.PosYMutator,PosYAccessor.PosYProperty
public class PositionPropertyBuilder extends PositionImpl implements Position.PositionProperty, Position.PositionBuilder<PositionPropertyBuilder>
The Class PositionPropertyBuilder.
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.graphical.Position
Position.PositionBuilder<B extends Position.PositionBuilder<B>>, Position.PositionMutator, Position.PositionProperty
-
Nested classes/interfaces inherited from interface org.refcodes.graphical.PosXAccessor
PosXAccessor.PosXBuilder<B extends PosXAccessor.PosXBuilder<B>>, PosXAccessor.PosXMutator, PosXAccessor.PosXProperty
-
Nested classes/interfaces inherited from interface org.refcodes.graphical.PosYAccessor
PosYAccessor.PosYBuilder<B extends PosYAccessor.PosYBuilder<B>>, PosYAccessor.PosYMutator, PosYAccessor.PosYProperty
-
-
Field Summary
-
Fields inherited from class org.refcodes.graphical.PositionImpl
_posX, _posY
-
-
Constructor Summary
Constructors Constructor Description PositionPropertyBuilder()Instantiates a new position property builder impl.PositionPropertyBuilder(int aPosX, int aPosY)Instantiates a new position property builder impl.
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description voidsetPosition(int aPosX, int aPosY)Sets the position.voidsetPosition(Position aPosition)Sets the position.voidsetPositionX(int aPosX)Sets the X position for the X position property.voidsetPositionY(int aPosY)Sets the Y position for the Y position property.PositionPropertyBuilderwithPosition(int aPosX, int aPosY)With position.PositionPropertyBuilderwithPosition(Position aPosition)With position.PositionPropertyBuilderwithPositionX(int aPosX)Sets the X position for the X position property.PositionPropertyBuilderwithPositionY(int aPosY)Sets the Y position for the Y position property.-
Methods inherited from class org.refcodes.graphical.PositionImpl
equals, getPositionX, getPositionY, hashCode, toString
-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface org.refcodes.graphical.Position.PositionProperty
addTo, letPosition, letPosition, subFrom
-
Methods inherited from interface org.refcodes.graphical.PosXAccessor
getPositionX
-
Methods inherited from interface org.refcodes.graphical.PosXAccessor.PosXProperty
letPositionX
-
Methods inherited from interface org.refcodes.graphical.PosYAccessor
getPositionY
-
Methods inherited from interface org.refcodes.graphical.PosYAccessor.PosYProperty
letPositionY
-
-
-
-
Constructor Detail
-
PositionPropertyBuilder
public PositionPropertyBuilder()
Instantiates a new position property builder impl.
-
PositionPropertyBuilder
public PositionPropertyBuilder(int aPosX, int aPosY)Instantiates a new position property builder impl.- Parameters:
aPosX- the pos XaPosY- the pos Y
-
-
Method Detail
-
setPositionX
public void setPositionX(int aPosX)
Sets the X position for the X position property.- Specified by:
setPositionXin interfacePosXAccessor.PosXMutator- Parameters:
aPosX- The X position to be stored by the X position property.
-
withPositionX
public PositionPropertyBuilder withPositionX(int aPosX)
Sets the X position for the X position property.- Specified by:
withPositionXin interfacePosXAccessor.PosXBuilder<PositionPropertyBuilder>- Parameters:
aPosX- The X position to be stored by the X position property.- Returns:
- The builder for applying multiple build operations.
-
setPositionY
public void setPositionY(int aPosY)
Sets the Y position for the Y position property.- Specified by:
setPositionYin interfacePosYAccessor.PosYMutator- Parameters:
aPosY- The Y position to be stored by the Y position property.
-
withPositionY
public PositionPropertyBuilder withPositionY(int aPosY)
Sets the Y position for the Y position property.- Specified by:
withPositionYin interfacePosYAccessor.PosYBuilder<PositionPropertyBuilder>- Parameters:
aPosY- The Y position to be stored by the Y position property.- Returns:
- The builder for applying multiple build operations.
-
withPosition
public PositionPropertyBuilder withPosition(int aPosX, int aPosY)
With position.- Specified by:
withPositionin interfacePosition.PositionBuilder<PositionPropertyBuilder>- Parameters:
aPosX- the pos XaPosY- the pos Y- Returns:
- the b
-
withPosition
public PositionPropertyBuilder withPosition(Position aPosition)
With position.- Specified by:
withPositionin interfacePosition.PositionBuilder<PositionPropertyBuilder>- Parameters:
aPosition- the position- Returns:
- the b
-
setPosition
public void setPosition(int aPosX, int aPosY)Sets the position.- Specified by:
setPositionin interfacePosition.PositionMutator- Parameters:
aPosX- the pos XaPosY- the pos Y
-
setPosition
public void setPosition(Position aPosition)
Sets the position.- Specified by:
setPositionin interfacePosition.PositionMutator- Parameters:
aPosition- the new position
-
-