Interface Rectangle.RectangleProperty

  • Method Details

    • letRectangle

      default Rectangle letRectangle(Rectangle aRectangle)
      This method stores and passes through the given argument, which is very useful for builder APIs: Sets the given Rectangle (setter) as of Rectangle.RectangleMutator.setRectangle(Rectangle) and returns the very same value (getter).
      Parameters:
      aRectangle - The new rectangle's metrics to set (via Rectangle.RectangleMutator.setRectangle(Rectangle)).
      Returns:
      Returns the value passed for it to be used in conclusive processing steps.
    • letRectangle

      default Rectangle letRectangle(int aPositionX, int aPositionY, int aWidth, int aHeight)
      This method stores and passes through the given arguments, which is very useful for builder APIs: Sets the given Rectangle (setter) as of Rectangle.RectangleMutator.setRectangle(int, int, int, int) and returns the very same value encapsulated as Rectangle instance.
      Parameters:
      aPositionX - The X position of the rectangle.
      aPositionY - The Y position of the rectangle.
      aWidth - The width of the rectangle.
      aHeight - The height of the rectangle.
      Returns:
      Returns the values passed encapsulated in a Rectangle object for it to be used in conclusive processing steps.