Interface Rectangle.RectangleProperty
- All Superinterfaces:
Dimension,Dimension.DimensionAccessor,Dimension.DimensionMutator,Dimension.DimensionProperty,HeightAccessor,HeightAccessor.HeightMutator,HeightAccessor.HeightProperty,Position,Position.PositionMutator,Position.PositionProperty,PosXAccessor,PosXAccessor.PosXMutator,PosXAccessor.PosXProperty,PosYAccessor,PosYAccessor.PosYMutator,PosYAccessor.PosYProperty,Rectangle,Rectangle.RectangleMutator,WidthAccessor,WidthAccessor.WidthMutator,WidthAccessor.WidthProperty
- Enclosing interface:
Rectangle
public static interface Rectangle.RectangleProperty
extends Rectangle, Rectangle.RectangleMutator, Dimension.DimensionProperty, Position.PositionProperty
Provides a property (getter / setter) for a rectangle property (dimension
and height).
-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.graphical.Dimension
Dimension.DimensionAccessor, Dimension.DimensionBuilder<B extends Dimension.DimensionBuilder<B>>, Dimension.DimensionMutator, Dimension.DimensionPropertyNested classes/interfaces inherited from interface org.refcodes.graphical.HeightAccessor
HeightAccessor.HeightBuilder<B extends HeightAccessor.HeightBuilder<B>>, HeightAccessor.HeightMutator, HeightAccessor.HeightPropertyNested classes/interfaces inherited from interface org.refcodes.graphical.Position
Position.PositionBuilder<B extends Position.PositionBuilder<B>>, Position.PositionMutator, Position.PositionPropertyNested classes/interfaces inherited from interface org.refcodes.graphical.PosXAccessor
PosXAccessor.PosXBuilder<B extends PosXAccessor.PosXBuilder<B>>, PosXAccessor.PosXMutator, PosXAccessor.PosXPropertyNested classes/interfaces inherited from interface org.refcodes.graphical.PosYAccessor
PosYAccessor.PosYBuilder<B extends PosYAccessor.PosYBuilder<B>>, PosYAccessor.PosYMutator, PosYAccessor.PosYPropertyNested classes/interfaces inherited from interface org.refcodes.graphical.Rectangle
Rectangle.RectangleBuilder<B extends Rectangle.RectangleBuilder<B>>, Rectangle.RectangleMutator, Rectangle.RectanglePropertyNested classes/interfaces inherited from interface org.refcodes.graphical.WidthAccessor
WidthAccessor.WidthBuilder<B extends WidthAccessor.WidthBuilder<B>>, WidthAccessor.WidthMutator, WidthAccessor.WidthProperty -
Method Summary
Modifier and TypeMethodDescriptiondefault RectangleletRectangle(int aPositionX, int aPositionY, int aWidth, int aHeight) This method stores and passes through the given arguments, which is very useful for builder APIs: Sets the givenRectangle(setter) as ofRectangle.RectangleMutator.setRectangle(int, int, int, int)and returns the very same value encapsulated asRectangleinstance.default RectangleletRectangle(Rectangle aRectangle) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenRectangle(setter) as ofRectangle.RectangleMutator.setRectangle(Rectangle)and returns the very same value (getter).Methods inherited from interface org.refcodes.graphical.Dimension.DimensionMutator
setDimension, setDimensionMethods inherited from interface org.refcodes.graphical.Dimension.DimensionProperty
letDimension, letDimensionMethods inherited from interface org.refcodes.graphical.HeightAccessor
getHeightMethods inherited from interface org.refcodes.graphical.HeightAccessor.HeightMutator
setHeightMethods inherited from interface org.refcodes.graphical.HeightAccessor.HeightProperty
letHeightMethods inherited from interface org.refcodes.graphical.Position.PositionMutator
setPosition, setPositionMethods inherited from interface org.refcodes.graphical.Position.PositionProperty
addTo, letPosition, letPosition, subFromMethods inherited from interface org.refcodes.graphical.PosXAccessor
getPositionXMethods inherited from interface org.refcodes.graphical.PosXAccessor.PosXMutator
setPositionXMethods inherited from interface org.refcodes.graphical.PosXAccessor.PosXProperty
letPositionXMethods inherited from interface org.refcodes.graphical.PosYAccessor
getPositionYMethods inherited from interface org.refcodes.graphical.PosYAccessor.PosYMutator
setPositionYMethods inherited from interface org.refcodes.graphical.PosYAccessor.PosYProperty
letPositionYMethods inherited from interface org.refcodes.graphical.Rectangle.RectangleMutator
setRectangle, setRectangleMethods inherited from interface org.refcodes.graphical.WidthAccessor
getWidthMethods inherited from interface org.refcodes.graphical.WidthAccessor.WidthMutator
setWidthMethods inherited from interface org.refcodes.graphical.WidthAccessor.WidthProperty
letWidth
-
Method Details
-
letRectangle
This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenRectangle(setter) as ofRectangle.RectangleMutator.setRectangle(Rectangle)and returns the very same value (getter).- Parameters:
aRectangle- The new rectangle's metrics to set (viaRectangle.RectangleMutator.setRectangle(Rectangle)).- Returns:
- Returns the value passed for it to be used in conclusive processing steps.
-
letRectangle
This method stores and passes through the given arguments, which is very useful for builder APIs: Sets the givenRectangle(setter) as ofRectangle.RectangleMutator.setRectangle(int, int, int, int)and returns the very same value encapsulated asRectangleinstance.- Parameters:
aPositionX- The X position of the rectangle.aPositionY- The Y position of the rectangle.aWidth- The width of the rectangle.aHeight- The height of the rectangle.- Returns:
- Returns the values passed encapsulated in a
Rectangleobject for it to be used in conclusive processing steps.
-