Interface RightPaddingAccessor
- All Known Subinterfaces:
Padding,Padding.PaddingAccessor,Padding.PaddingProperty,RightPaddingAccessor.RightPaddingProperty
public interface RightPaddingAccessor
Provides an accessor for a right padding property.
-
Nested Class Summary
Nested ClassesModifier and TypeInterfaceDescriptionstatic interfaceProvides a builder method for a right padding property returning the builder for applying multiple build operations.static interfaceProvides a mutator for a right padding property.static interfaceProvides a right padding property. -
Method Summary
Modifier and TypeMethodDescriptionintRetrieves the right padding from the right padding property.
-
Method Details
-
getRightPadding
int getRightPadding()Retrieves the right padding from the right padding property.- Returns:
- The right padding stored by the right padding property.
-