Module org.refcodes.graphical
Package org.refcodes.graphical
Interface TopPaddingAccessor.TopPaddingMutator
- All Known Subinterfaces:
Padding.PaddingMutator,Padding.PaddingProperty,TopPaddingAccessor.TopPaddingProperty
- Enclosing interface:
- TopPaddingAccessor
public static interface TopPaddingAccessor.TopPaddingMutator
Provides a mutator for a top padding property.
-
Method Summary
Modifier and TypeMethodDescriptionvoidsetTopPadding(int aTopPadding) Sets the top padding for the top padding property.
-
Method Details
-
setTopPadding
void setTopPadding(int aTopPadding) Sets the top padding for the top padding property.- Parameters:
aTopPadding- The top padding to be stored by the top padding property.
-