- All Known Subinterfaces:
Vector,Vector.VectorProperty,VectorXAccessor.VectorXProperty
public interface VectorXAccessor
Provides an accessor for a X vector property.
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceVectorXAccessor.VectorXBuilder<B extends VectorXAccessor.VectorXBuilder<B>>Provides a builder method for a X vector property returning the builder for applying multiple build operations.static interfaceVectorXAccessor.VectorXMutatorProvides a mutator for a X vector property.static interfaceVectorXAccessor.VectorXPropertyProvides a X vector property. -
Method Summary
Modifier and Type Method Description intgetVectorX()Retrieves the X vector from the X vector property.
-
Method Details
-
getVectorX
int getVectorX()Retrieves the X vector from the X vector property.- Returns:
- The X vector stored by the X vector property.
-