Uses of Class
org.refcodes.graphical.GridMode
-
-
Uses of GridMode in org.refcodes.graphical
Fields in org.refcodes.graphical declared as GridMode Modifier and Type Field Description protected GridModeRasterImpl. _gridModeMethods in org.refcodes.graphical that return GridMode Modifier and Type Method Description GridModeGridModeAccessor. getGridMode()Retrieves the grid mode from the grid mode property.GridModeRasterImpl. getGridMode()Retrieves the grid mode from the grid mode property.default GridModeGridModeAccessor.GridModeProperty. letGridMode(GridMode aGridMode)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenGridMode(setter) as ofGridModeAccessor.GridModeMutator.setGridMode(GridMode)and returns the very same value (getter).static GridModeGridMode. valueOf(String name)Returns the enum constant of this type with the specified name.static GridMode[]GridMode. values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in org.refcodes.graphical with parameters of type GridMode Modifier and Type Method Description default GridModeGridModeAccessor.GridModeProperty. letGridMode(GridMode aGridMode)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenGridMode(setter) as ofGridModeAccessor.GridModeMutator.setGridMode(GridMode)and returns the very same value (getter).voidGridModeAccessor.GridModeMutator. setGridMode(GridMode aGridMode)Sets the grid mode for the grid mode property.voidRasterPropertyBuilder. setGridMode(GridMode aGridMode)Sets the grid mode for the grid mode property.BGridModeAccessor.GridModeBuilder. withGridMode(GridMode aGridMode)Sets the grid mode for the grid mode property.RasterPropertyBuilderRasterPropertyBuilder. withGridMode(GridMode aGridMode)Sets the grid mode for the grid mode property.Constructors in org.refcodes.graphical with parameters of type GridMode Constructor Description RasterImpl(int aGridWidth, int aGridHeight, int aWidth, int aHeight, int aGap, GridMode aGridMode)Instantiates a new raster impl.RasterPropertyBuilder(int aGridWidth, int aGridHeight, int aWidth, int aHeight, int aGap, GridMode aGridMode)Instantiates a new raster property builder impl.
-