Uses of Class
org.refcodes.graphical.LayoutMode
-
-
Uses of LayoutMode in org.refcodes.graphical
Methods in org.refcodes.graphical that return LayoutMode Modifier and Type Method Description LayoutModeLayoutModeAccessor. getLayoutMode()Retrieves the layout mode from the layout mode property.default LayoutModeLayoutModeAccessor.LayoutModeProperty. letLayoutMode(LayoutMode aLayoutMode)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenLayoutMode(setter) as ofLayoutModeAccessor.LayoutModeMutator.setLayoutMode(LayoutMode)and returns the very same value (getter).static LayoutModeLayoutMode. valueOf(String name)Returns the enum constant of this type with the specified name.static LayoutMode[]LayoutMode. values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in org.refcodes.graphical with parameters of type LayoutMode Modifier and Type Method Description default LayoutModeLayoutModeAccessor.LayoutModeProperty. letLayoutMode(LayoutMode aLayoutMode)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenLayoutMode(setter) as ofLayoutModeAccessor.LayoutModeMutator.setLayoutMode(LayoutMode)and returns the very same value (getter).voidLayoutModeAccessor.LayoutModeMutator. setLayoutMode(LayoutMode aLayoutMode)Sets the layout mode for the layout mode property.BLayoutModeAccessor.LayoutModeBuilder. withLayoutMode(LayoutMode aLayoutMode)Sets the layout mode for the layout mode property.
-