Uses of Interface
org.refcodes.graphical.Offset
-
-
Uses of Offset in org.refcodes.graphical
Subinterfaces of Offset in org.refcodes.graphical Modifier and Type Interface Description static interfaceOffset.OffsetPropertyThe Interface OffsetProperty.Methods in org.refcodes.graphical that return Offset Modifier and Type Method Description default OffsetOffset.OffsetProperty. letOffset(int aOffsetX, int aOffsetY)This method stores and passes through the given arguments, which is very useful for builder APIs: Sets the givenDimension(setter) as ofOffset.OffsetMutator.setOffset(int, int)and returns the very same values encapsulated asOffsetinstance.default OffsetOffset.OffsetProperty. letOffset(Offset aOffset)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenOffset(setter) as ofOffset.OffsetMutator.setOffset(Offset)and returns the very same value (getter).Methods in org.refcodes.graphical with parameters of type Offset Modifier and Type Method Description static booleanOffset. equals(Offset aOffsetA, Offset aOffsetB)Equals.default OffsetOffset.OffsetProperty. letOffset(Offset aOffset)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenOffset(setter) as ofOffset.OffsetMutator.setOffset(Offset)and returns the very same value (getter).voidGridOffset.GridOffsetMutator. setGridOffset(Offset aOffset)Sets the grid offset.voidOffset.OffsetMutator. setOffset(Offset aOffset)Sets the offset.voidViewportOffset.ViewportOffsetMutator. setViewportOffset(Offset aOffset)Sets the viewport offset.BGridOffset.GridOffsetBuilder. withGridOffset(Offset aOffset)With grid offset.BOffset.OffsetBuilder. withOffset(Offset aOffset)With offset.BViewportOffset.ViewportOffsetBuilder. withViewportOffset(Offset aOffset)With viewport offset.
-