Uses of Enum
org.refcodes.graphical.PixelShape
-
Uses of PixelShape in org.refcodes.graphical
Methods in org.refcodes.graphical that return PixelShapeModifier and TypeMethodDescriptionPixGridPane.getPixelShape()Gets the pixel shape.static PixelShapeReturns the enum constant of this type with the specified name.static PixelShape[]PixelShape.values()Returns an array containing the constants of this enum type, in the order they are declared.