Uses of Interface
org.refcodes.graphical.Rectangle
-
-
Uses of Rectangle in org.refcodes.graphical
Subinterfaces of Rectangle in org.refcodes.graphical Modifier and Type Interface Description static interfaceRectangle.RectanglePropertyProvides a property (getter / setter) for a rectangle property (dimension and height).Classes in org.refcodes.graphical that implement Rectangle Modifier and Type Class Description classRectangleImplThe classRectangleImplimplements theRectangleinterface.Methods in org.refcodes.graphical that return Rectangle Modifier and Type Method Description default RectangleRectangle.RectangleProperty. letRectangle(int aPositionX, int aPositionY, int aWidth, int aHeight)This method stores and passes through the given arguments, which is very useful for builder APIs: Sets the givenRectangle(setter) as ofRectangle.RectangleMutator.setRectangle(int, int, int, int)and returns the very same value encapsulated asRectangleinstance.default RectangleRectangle.RectangleProperty. letRectangle(Rectangle aRectangle)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenRectangle(setter) as ofRectangle.RectangleMutator.setRectangle(Rectangle)and returns the very same value (getter).Methods in org.refcodes.graphical with parameters of type Rectangle Modifier and Type Method Description booleanPixGridPanel. addBlankArea(Rectangle aArea)Adds the blank area not to be painted with grid pixels.static booleanRectangle. equals(Rectangle aRectangleA, Rectangle aRectangleB)Equals.default RectangleRectangle.RectangleProperty. letRectangle(Rectangle aRectangle)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenRectangle(setter) as ofRectangle.RectangleMutator.setRectangle(Rectangle)and returns the very same value (getter).booleanPixGridPanel. removeBlankArea(Rectangle aArea)Removes the blank area now to be painted with grid pixels again.voidRectangle.RectangleMutator. setRectangle(Rectangle aRectangle)Sets the rectangle.BRectangle.RectangleBuilder. withRectangle(Rectangle aRectangle)With rectangle.
-