Uses of Class
org.refcodes.graphical.ScaleMode
-
-
Uses of ScaleMode in org.refcodes.graphical
Methods in org.refcodes.graphical that return ScaleMode Modifier and Type Method Description ScaleModeScaleModeAccessor. getScaleMode()Retrieves the scale mode from the scale mode property.default ScaleModeScaleModeAccessor.ScaleModeProperty. letScaleMode(ScaleMode aScaleMode)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenScaleMode(setter) as ofScaleModeAccessor.ScaleModeMutator.setScaleMode(ScaleMode)and returns the very same value (getter).static ScaleModeScaleMode. valueOf(String name)Returns the enum constant of this type with the specified name.static ScaleMode[]ScaleMode. values()Returns an array containing the constants of this enum type, in the order they are declared.Methods in org.refcodes.graphical with parameters of type ScaleMode Modifier and Type Method Description default ScaleModeScaleModeAccessor.ScaleModeProperty. letScaleMode(ScaleMode aScaleMode)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenScaleMode(setter) as ofScaleModeAccessor.ScaleModeMutator.setScaleMode(ScaleMode)and returns the very same value (getter).voidScaleModeAccessor.ScaleModeMutator. setScaleMode(ScaleMode aScaleMode)Sets the scale mode for the scale mode property.BScaleModeAccessor.ScaleModeBuilder. withScaleMode(ScaleMode aScaleMode)Sets the scale mode for the scale mode property.
-